/*******************************************************************************
							
	       Poverty and Equity Assessment for El Salvador 2024
******************************************************************************

*Do file: Additional indicators
*Last update: 26/11/2024
===============================================================================*/

* Set project global(s)
	
	global path = "/Users/sofiahidalgo/Library/Mobile Documents/com~apple~CloudDocs/Documents/PEA_SLV_2024"
	global data = "/$path/Data" 
	global exp ="/$path/Results/Additional Indicators"
	global code ="/$path/Do files"

************************************************************************************


*Chapter 1

***1.1 Two decades of poverty reduction, and new trends

///

*****************************
*	Poverty by area, age and region *
*****************************


foreach y of numlist 2000 2023{ 
u  "$data/SLV/SLV_`y'", replace
encode region_est2, gen(region)

recode edad (0/14=1) (15/24=2) (25/59=3) (60/max=4), gen(gedad)	
	putexcel B1=("Poverty")
	
tabout urbano pobreza  [w=pondera] using "$exp/1.1povarea-region-age`y'.xls", replace
tabout gedad pobreza [w=pondera] using "$exp/1.1povarea-region-age`y'.xls", append
tabout region pobreza [w=pondera] using "$exp/1.1povarea-region-age`y'.xls", append
}


******************************
*	HH average remittances *
*****************************
foreach y of numlist 2000 2019 2023{
u  "$data/SLV/SLV_`y'", replace
*Using right incomes (not adjusted by rurality)
replace itranext_m=itranext_m*p_reg

*Creating income variables at household level
egen priextf=sum(itranext_m), by(id)

cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17a=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion)

xtile percentil=ingpe [w=pondera] if r103==1, n(5)

gen rem=priext*factor_ppp17a if r103==1

*Per=1 if percentil 1, Per=2 if percentil>1
gen per=1 if percentil==1
replace per=2 if percentil>1 & percentil!=.

tabstat rem [w=pondera] if r103==1, stats(mean) by(per)

}

*****************************
*	HH benefits from social protection *
*****************************


local row=2
foreach y of numlist 2009 2019 2023{ 
u  "$data/SLV/SLV_`y'", replace

egen itranef=sum(itrane_m), by(id)

gen recibe=1 if itranef>0 & itranef!=.
replace recibe=0 if itranef==0 | itranef==.



putexcel set "$exp/1.1Socialprotection.xls", modify
putexcel A1=("`y'") B1=("Assitance - HH pobres") C1=("Average transfer")
sum recibe if pobre==1 & r103==1  [w=pondera]
putexcel B`row'=(r(mean))
sum itrane_m if itrane!=0 & pobre==1 & r103==1  [w=pondera]
putexcel C`row'=(r(mean))

local ++row
}



*****************************
*	Transisiciones educativas *
*****************************


use "$data/SLV/SLV_2023", clear


gen hijo1=1 if r103==3
egen hijo1a=max(hijo1), by(id)

gen padre1=1 if r103==4
egen padre1a=max(padre1), by(id)

gen hijos=1 if r103==3 | (r103==1 & padre1a==1)
gen padres=1 if r103==4 | ((r103==1 | r103==2) & hijo1a==1)

gen nivel_padres=nivel if padres==1
gen nivel_hijos1=nivel if hijos==1 & edad>=24 & edad<34
gen nivel_hijos2=nivel if hijos==1 & edad>=34 & edad<44
gen nivel_hijos3=nivel if hijos==1 & edad>=44 & edad<54

egen nivpf=max(nivel_padres), by(idboleta)
egen nivhf1=max(nivel_hijos1), by(idboleta)
egen nivhf2=max(nivel_hijos2), by(idboleta)
egen nivhf3=max(nivel_hijos3), by(idboleta)

tabout nivpf nivhf1 [w=pondera] if r103==1 using "$exp/1.1Educationaltransitions.xls" , replace 
tabout nivpf nivhf2 [w=pondera] if r103==1 using "$exp/1.1Educationaltransitions.xls", append 
tabout nivpf nivhf3 [w=pondera] if r103==1 using "$exp/1.1Educationaltransitions.xls", append 


gen psec=1 if nivpf>=4 & nivpf!=.
replace psec=0 if nivpf<=3

gen hsec1=1 if nivhf1>=4 & nivhf1!=.
replace hsec=0 if nivhf1<=3

gen hsec2=1 if nivhf2>=4 & nivhf2!=.
replace hsec2=0 if nivhf2<=3

gen hsec3=1 if nivhf3>=4 & nivhf3!=.
replace hsec3=0 if nivhf3<=3

tabout hsec1 if r103==1 & psec==0 [w=pondera] using "$exp/1.1Educationaltransitions.xls", append
tabout hsec2 if r103==1 & psec==0 [w=pondera] using "$exp/1.1Educationaltransitions.xls", append
tabout hsec3 if r103==1 & psec==0 [w=pondera] using "$exp/1.1Educationaltransitions.xls", append


*****************************
*	Sectoral employment share and real incomes *
*****************************

foreach y of numlist 2019 2023{
u  "$data/SLV/SLV_`y'", replace

*Using right incomes (not adjusted by rurality)
replace ila=ila*p_reg

*Creating sector vari
gen sec=1 if r420==2 | r420==3
replace sec=2 if (sector1d<=3) & r420==1
replace sec=3 if (sector1d==4) & r420==1
replace sec=4 if ((sector1d>=5 & sector1d<=9) | sector1d==15) & r420==1
replace sec=4 if (sector1d==13 | sector1d==14 | sector1d==17) & r420==1
replace sec=5 if (sector1d==10 | sector1d==11) & r420==1
replace sec=6 if sector1d==16

label define sec 1 "Public administration" 2 "Agriculture and fishing" 3 "Manufacturing" 4 "Services" 5 "Finance and rental activities" 6 "Domestic services" 
label values sec sec

*Quintiles del ingreso per capita 
xtile decil=ingpe [w=pondera] if r103==1, n(5)
egen decil1=min(decil), by(id)

*Diferenciar quintil 1 de los demás quintiles
gen quintil=1 if decil1==1
replace quintil=2 if decil1>1 & decil1<=5 

*Real earnings
cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion)

gen ila_ppp17=ila*factor_ppp17


tabout sec [w=pondera] if ila!=0 & quintil==1  using "$exp/1.1Sectoralemployment`y'.xls", replace
tabout sec using "$exp/1.1Sectoralemployment`y'.xls" if ila!=0 & quintil==1 [w=pondera], append sum ///
    c(mean  ila_ppp17) ///
    f(2) style(xlsx) clab("Lab. Income")
	
tabout sec [w=pondera] if ila!=0 & quintil==2  using "$exp/1.1Sectoralemployment`y'.xls", append
tabout sec using "$exp/1.1Sectoralemployment`y'.xls" if ila!=0 & quintil==2 [w=pondera], append sum ///
    c(mean  ila_ppp17) ///
    f(2) style(xlsx) clab("Lab. Income")
	
}



*****************************
*	HH members and working members *
*****************************

foreach x of numlist 2019  2023{ 
	u  "$data/SLV/SLV_`x'", replace 
cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion)

*percentiles de ingreso del hogar
xtile [w=pondera] peringpe=ingpe, nq(5)

*Miembros que trabajan 

bysort id: gen miemocu=1 if ocupado==1 & sector1d!=16
bysort id: egen miemocuh=total(miemocu)
bysort id: gen ratiomiem=miemocuh/miemh_exdomestico

collapse (first) miemh_exdomestico miemocuh peringpe ratiomiem urbano [w=pondera], by(id)

preserve 
collapse (mean) miemh_exdomestico miemocuh ratiomiem, by(peringpe)

export excel using "$exp/1.1HHmembersandworkingmembers`x'.xls", firstrow(variables) replace
restore

}


*=========================================================================
*Chapter 2
*=========================================================================

u  "$data/SLV/SLV_2023", replace

*Using right incomes (not adjusted by rurality)
replace ila=ila*p_reg
replace ictap=ictap*p_reg
replace itranp=itranp*p_reg
replace itrane=itrane*p_reg
replace itranext_m=itranext_m*p_reg
replace itranint_m=itranint_m*p_reg
replace icap=icap*p_reg
replace ijubi=ijubi*p_reg
replace ijubi_ncon=ijubi_ncon*p_reg
replace ijubi_con=ijubi_con*p_reg
replace inla_otro=inla_otro*p_reg
replace inla=inla*p_reg

*Generating variable for dependent income
recode ila ictap (.=0)
gen labasal=ila-ictap

*Creating income variables at household level
egen labdf=sum(labasal), by(idboleta)
egen labif=sum(ictap), by(idboleta)
egen retirementcon=sum(ijubi_con), by(idboleta)
egen retirementnocon=sum(ijubi_ncon), by(idboleta)
egen retirement=sum(ijubi), by(idboleta)
egen pubtf=sum(itrane), by(idboleta)
egen pritf=sum(itranp), by(idboleta)
egen pridomf=sum(itranint_m), by(idboleta)
egen priextf=sum(itranext_m), by(idboleta)
egen capitalf=sum(icap), by(idboleta)
egen otrosf=sum(inla_otro), by(idboleta)

egen ingresof=rsum(labdf labif pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1
egen ingnlg=rsum(pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1
tabstat ingnlg if r103==1 & area==1 [w=pondera], stats(mean) by(pobreza)
tabstat ingnlg if r103==1 & area==0 [w=pondera], stats(mean) by(pobreza)



*****************************
*	Calculating labor incomes, by characteristics of the head of household
*****************************

recode edad (0/14=1) (15/24=2) (25/64=3) (65/max=4), gen(gedad)	

tabstat labdf labif if r103==1  & area==1 [w=pondera], stats(mean) by(hombre)
tabstat labdf labif if r103==1  & area==0 [w=pondera], stats(mean) by(hombre)


tabstat labdf labif if r103==1  & area==1 [w=pondera], stats(mean) by(gedad)
tabstat labdf labif if r103==1  & area==0 [w=pondera], stats(mean) by(gedad)


local row=2
foreach x in ila labdf labif {
preserve
keep if urban==1
	putexcel set "$exp/2.1LaborincomeHHcharact.xls", modify	
	putexcel A1=("`y'") B1=("Female") C1=("Male") D1=("Age 0-14") E1=("Age 15-24") F1=("Age 25-59") G1=("Age 60+")
	putexcel A`row'=("Urban")

	summ `x' [w=pondera] if hombre==0
	putexcel B`row'=(r(mean))
	summ `x' [w=pondera] if hombre==1
	putexcel C`row'=(r(mean))
	summ `x' [w=pondera] if gedad==1
	putexcel D`row'=(r(mean))
	summ `x' [w=pondera] if gedad==2
	putexcel E`row'=(r(mean))
	summ `x' [w=pondera] if gedad==3
	putexcel F`row'=(r(mean))
	summ `x' [w=pondera] if gedad==4
	putexcel G`row'=(r(mean))
	local ++row
	
restore
}

local row=5
foreach x in ila labdf labif {
preserve
keep if urban==0
	putexcel set "$exp/2.1LaborincomeHHcharact.xls", modify	
	putexcel A1=("`y'") B1=("Female") C1=("Male") D1=("Age 0-14") E1=("Age 15-24") F1=("Age 25-59") G1=("Age 60+")
	putexcel A`row'=("Rural")

	summ `x' [w=pondera] if hombre==0
	putexcel B`row'=(r(mean))
	summ `x' [w=pondera] if hombre==1
	putexcel C`row'=(r(mean))
	summ `x' [w=pondera] if gedad==1
	putexcel D`row'=(r(mean))
	summ `x' [w=pondera] if gedad==2
	putexcel E`row'=(r(mean))
	summ `x' [w=pondera] if gedad==3
	putexcel F`row'=(r(mean))
	summ `x' [w=pondera] if gedad==4
	putexcel G`row'=(r(mean))
	local ++row
	
restore
}



*****************************
*	Calculating labor instability *
*****************************

gen wap=1 if edad>=16


tabout r418  [w=pondera] using "$exp/2.1jobinstability.xls", replace
tabout r418 contrato  [w=pondera] using "$exp/2.1jobinstability.xls", append
*Poverty rate, by labor instability
tabout contrato pobre if wap==1 &  relab==2 [w=pondera] using "$exp/2.1jobinstability.xls", append
*Gender by labor instability
tabout hombre contrato if wap==1 &  relab==2 [w=pondera] using "$exp/2.1jobinstability.xls", append
*Area by labor instability
tabout contrato area if wap==1 &  relab==2 [w=pondera] using "$exp/2.1jobinstability.xls", append
*Age by labor instability
tabout contrato gedad if wap==1 &  relab==2 [w=pondera] using "$exp/2.1jobinstability.xls", append
*Nivel by labor instability
tabout nivel contrato if wap==1 &  relab==2 [w=pondera] using "$exp/2.1jobinstability.xls", append


tab r418 contrato [w=pondera] if wap==1, row nofreq
tabstat contrato [w=pondera] if wap==1, by(hombre)
tabstat contrato [w=pondera] if wap==1, by(area)
tabstat contrato [w=pondera] if wap==1, by(gedad1)
tabstat contrato [w=pondera] if wap==1, by(nivel)


tab gedad [w=pondera] if contrato==0 & wap==1 & area==1


*****************************
*	Calculating underemployment *
*****************************

*Underemployment
tab r418 actse [w=pondera] if wap==1
tab r418 actse [w=pondera] if wap==1, row nofreq
gen under=1 if actse==2 | actse==3
replace under=0 if actse==1


*Poverty rates, by labor instability
tabout pobreza under if wap==1 [w=pondera] using "$exp/2.1underemployment.xls", replace
*Gender by labor instability
tabout hombre under if wap==1  [w=pondera] using "$exp/2.1underemployment.xls", append
*Area by labor instability
tabout area under if wap==1  [w=pondera] using "$exp/2.1underemployment.xls", append
*Age by labor instability
tabout gedad under if wap==1  [w=pondera] using "$exp/2.1underemployment.xls", append
*Nivel by labor instability
tabout nivel under if wap==1  [w=pondera] using "$exp/2.1underemployment.xls", append


*****************************
*	Calculating inadequacy *
*****************************


*Calculating over 40 hours, by poverty status

gen sobre=1 if hstrt>40 & hstrt!=.
replace sobre=0 if hstrt<=40 & hstrt!=0
tabstat sobre if wap==1 [w=pondera], stats(mean) by(pobreza)
table pobreza relab if wap==1 [w=pondera], c(mean sobre)

*Calculating multiple jobs, by poverty status
gen doble=1 if hstrp>0 & hstrp!=. & hstrs>0 & hstrs!=.
replace doble=0 if hstrp>0 & hstrp!=. & hstrs==.
tabstat doble if wap==1 [w=pondera], stats(mean) by(pobreza)
table pobreza relab if wap==1 [w=pondera], c(mean doble)


*Poverty rates, by labor inadequacy (+40 hours)
tabout pobreza sobre if wap==1 [w=pondera] using "$exp/2.1inadequacy.xls", replace
*Type of employment by labor inadequacy (+40 hours)
tabout relab pobreza if wap==1 & sobre==1 [w=pondera] using "$exp/2.1inadequacy.xls", append
*Poverty rates, by labor inadequacy (+1 job)
tabout pobreza doble if wap==1 [w=pondera] using "$exp/2.1inadequacy.xls", append
*Type of employment by labor inadequacy (+1job)
tabout relab doble if wap==1 [w=pondera] using "$exp/2.1inadequacy.xls", append

*Ocupacion secundaria El Salvador
recode edad (14=0 "14") (15/19=1 "Edad: 15-19") ///
(20/24=2 "Edad: 20-24") (25/29=3 "Edad: 25-29") (30/34=4  "Edad: 30-34") ///
(35/39=5 "Edad: 35-39") (40/44=6 "Edad: 40-44") (45/49=7  "Edad: 45-49") ///
(50/54=8 "Edad: 50-54") (55/59=9 "Edad: 55-59") (60/64=10 "Edad: 60-64") (65/69=11 "Edad: 65-69") (70/74=12 "Edad: 70-74") (75/max=13 "Edad: 75+")(.=14 "NE"), gen(edad5)


*Age by labor inadequacy (+1job) in poor households
tabout edad5 doble if wap==1 & pobre==1 [w=pondera] using "$exp/2.1inadequacy.xls", append

/*
preserve
foreach x of numlist 2001 2019 2022 {
u  "$data/SLV/SLV_`x'", replace 

gen wap=1 if edad>=16
gen doble=1 if hstrp>0 & hstrp!=. & hstrs>0 & hstrs!=.
replace doble=0 if hstrp>0 & hstrp!=. & hstrs==.

*Ocupacion secundaria El Salvador
recode edad (14=0 "14") (15/19=1 "Edad: 15-19") ///
(20/24=2 "Edad: 20-24") (25/29=3 "Edad: 25-29") (30/34=4  "Edad: 30-34") ///
(35/39=5 "Edad: 35-39") (40/44=6 "Edad: 40-44") (45/49=7  "Edad: 45-49") ///
(50/54=8 "Edad: 50-54") (55/59=9 "Edad: 55-59") (60/64=10 "Edad: 60-64") (65/69=11 "Edad: 65-69") (70/74=12 "Edad: 70-74") (75/max=13 "Edad: 75+")(.=14 "NE"), gen(edad5)

gen ocusec=1 if njobs>=2
replace ocusec=0 if njobs==1
replace ocusec=. if njobs==. | relab_s==4


tabout edad5 ocusec [iw=pondera] if wap==1 using "$exp/2.1inadequacy.xls", append
}
restore
*/

*****************************
*	Calculating informality *
*****************************

*Defining formality status
replace tipo_seguro=. if ocupa==2 | ocupa==.
gen formal=1 if tipo_seguro<=1 & ocupa==1
replace formal=0 if tipo_seguro==. & ocupa==1

*Informality 
tabout formal if wap==1 [w=pondera] using "$exp/2.1informality.xls", replace
*Informality by area
tabout urbano formal if wap==1 [w=pondera] using "$exp/2.1informality.xls", append
*Informality by age
tabout gedad1 formal if wap==1 [w=pondera] using "$exp/2.1informality.xls", append
*Informality by gender
tabout hombre formal if wap==1 [w=pondera] using "$exp/2.1informality.xls", append

*Informality by sector
tabout sector1d formal if wap==1 [w=pondera] using "$exp/2.1informality.xls", append

replace r421=. if r421>900
gen size=1 if r421<=5 & labasal!=. & labasal!=0
replace size=2 if r421>5 & r421<=49 & labasal!=. & labasal!=0
replace size=3 if r421>49 & r421<=99 & labasal!=. & labasal!=0
replace size=4 if r421>99 & r421!=. & labasal!=. & labasal!=0

*Informality by sector and firmsize
tabout size formal if wap==1 [w=pondera] using "$exp/2.1informality.xls", append

*Informality by sector
tabout sector1d size if wap==1 & formal==0 [w=pondera] using "$exp/2.1informality.xls", append

*Informality by poverty
tabout pobreza formal if wap==1 [w=pondera] using "$exp/2.1informality.xls", append

*Labor income
tabout formal using "$exp/2.1informality.xls", append sum c(mean wage) f(2) ///
    style(xlsx) clab("Salario por hora Promedio")

	
*****************************
*	Calculating risk of automation *
*****************************

*Employment risk of automation
gen risk=1 if (sector1d==6 | sector1d==1 | sector1d==2 | sector1d==4 | sector1d==9) & wap==1 & relab<=30
replace risk=0 if risk==. & wap==1 & relab<=30
tab risk pobreza if wap==1 [w=pondera]
tab risk pobreza if wap==1 [w=pondera], col nofreq
tab pobreza risk if wap==1 [w=pondera], row nofreq


*Workers in risk of automation 

tabout risk if wap==1 [w=pondera] using "$exp/2.1riskofautomation.xls", replace

*Poor workers in risk of automation by area
tabout pobreza risk if wap==1 & urbano==0 [w=pondera]  using "$exp/2.1riskofautomation.xls", append

tabout pobreza risk if wap==1 & urbano==1 [w=pondera]  using "$exp/2.1riskofautomation.xls", append


*****************************
*	Calculating schooling premium for Males/Females and Capital city vs other regions *
*****************************


use "$data/SLV/SLV_2023", clear
append using "$data/SLV/SLV_2019", force
append using "$data/SLV/SLV_2009", force

cap drop d_informal
gen d_informal = .
		
replace d_informal = djubila == 0 if djubila != .
replace d_informal = . if ocupado != 1 | !inrange(relab,1,4)

* REMINDER: Always filter for coherent households.

keep if cohi==1
		
* Defining sample 
cap drop sample
gen sample = edad > 14 & edad < 65 

* Labor income (main occupation)
cap drop wage_ppp17
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)

gen wage_ppp17 = wage * (ipc17_sedlac / ipc_sedlac) / (ppp17 * conversion)

*Usando wage:
cap drop ln_wh
cap drop ln_whk
gen double ln_wh =ln(wage)
gen double ln_whk=ln(wage)

cap drop exp2
cap drop edad2
cap drop antigue2
gen exp2  = exp*exp 	
gen edad2 = edad*edad 
gen antigue2 = antigue*antigue

*Generar dummies para aedu
cap drop ae_*
replace aedu=17 if aedu>=17


foreach num in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 {
    *drop ae_*
	gen ae_`num'=0
	replace ae_`num'=1 if aedu==`num'
	label variable ae_`num' "`num'"
}

gen Haedu=aedu
replace Haedu=16 if aedu>=16

foreach num in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 {
    *drop Hae_*
	gen Hae_`num'=0
	replace Hae_`num'=1 if Haedu==`num'
	label variable Hae_`num' "`num'"
}

*Generar dummies para aedu EN SEGMENTOS
cap drop seg_aedu_*

gen seg_aedu_1=0
replace seg_aedu_1=. if aedu==.
replace seg_aedu_1=1 if aedu > 0 & aedu < 9

gen seg_aedu_2=0
replace seg_aedu_2=. if aedu==.
replace seg_aedu_2=1 if aedu > 8 & aedu < 13

gen seg_aedu_3=0
replace seg_aedu_3=. if aedu==.
replace seg_aedu_3=1 if aedu > 12

label variable seg_aedu_1 "Hasta 8"
label variable seg_aedu_2 "9 a 12"
label variable seg_aedu_3 "13 o más"


*Generar dummies para nivel
tab nivel, gen(niv_)

label variable niv_1 "No asis"
label variable niv_2 "Prim inc"
label variable niv_3 "Prim com"
label variable niv_4 "Sec inc"
label variable niv_5 "Sec com"
label variable niv_6 "Sup inc"
label variable niv_7 "Sup com"


tab nivedu, gen(nivedu_)

foreach num in 1 2 3 {
    label variable niv_`num' "`num'"
}

encode pais, generate(pais_i)

egen internet_casa_h=max(internet_casa), by(pais ano id)   

cap drop itrane_ppp17
gen itrane_ppp17 = itrane * (ipc17_sedlac / ipc_sedlac) / (ppp17 * conversion)
egen h_itrane = sum(itrane_ppp17) if jefe != ., by(pais ano id)

global var_reg Hae_1-Hae_16 edad edad2 i.hombre i.pais_i



***********
*1. Gender
************

// MAN
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2023 & hombre==1 & relab==2
estimates store total2023h
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2019 & hombre==1 & relab==2
estimates store total2019h
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2009 & hombre==1 & relab==2
estimates store total2009h

// WOMAN
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2023 & hombre==0 & relab==2
estimates store total2023m
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2019 & hombre==0 & relab==2
estimates store total2019m
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2009 & hombre==0 & relab==2
estimates store total2009m


// Gráficos

	
coefplot (total2009h, label(2009)) (total2019h, label(2019)) (total2023h, label(2023)), ///
	vertical drop(_cons edad edad2 *hombre *pais_i) yline(0) level(95) ci recast(connected) offset(0) msize(1pt)    ///
	graphregion(color(white)) ///
	legend(rows(1)) ///
	yscale(range(-0.5 2)) ///
	subtitle("Man")  ///
	title("Premium by year of schooling") ///
	b1title("Years of schooling") ///
	l1title("Schooling premium")
	graph export "$exp/schoolingpremiabygender-Males.png", replace
	
coefplot (total2009m, label(2009)) (total2019m, label(2019)) (total2023m, label(2023)), ///
	vertical drop(_cons edad edad2 *hombre *pais_i) yline(0) level(95) ci recast(connected) offset(0) msize(1pt)    ///
	graphregion(color(white)) ///
	legend(rows(1)) ///
	yscale(range(-0.5 2)) ///
	subtitle("Woman")  ///
	title("Premium by year of schooling") ///
	b1title("Years of schooling") ///
	l1title("Schooling premium")
	graph export "$exp/schoolingpremiabygender-Females.png", replace
	
*************************************  
*2 San Salvador vs other departments
*************************************
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2023 & relab==2 & r004==6
estimates store total2023h
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2019 & relab==2 & r004==6
estimates store total2019h
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2009 & relab==2 & r004==6
estimates store total2009h

// Otros
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2023 & relab==2 & r004!=6
estimates store total2023m
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2019 & relab==2 & r004!=6
estimates store total2019m
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2009 & relab==2 & r004!=6
estimates store total2009m


// Gráficos

	
coefplot (total2009h, label(2009)) (total2019h, label(2019)) (total2023h, label(2023)), ///
	vertical drop(_cons edad edad2 *hombre *pais_i) yline(0) level(95) ci recast(connected) offset(0) msize(1pt)    ///
	graphregion(color(white)) ///
	legend(rows(1)) ///
	yscale(range(-0.5 2)) ///
	subtitle("San Salvador")  ///
	title("Premium by year of schooling") ///
	b1title("Years of schooling") ///
	l1title("Schooling premium")
	graph export "$exp/schoolingpremiabyarea-SanSalvador.png", replace
	

coefplot (total2009m, label(2009)) (total2019m, label(2019)) (total2023m, label(2023)), ///
	vertical drop(_cons edad edad2 *hombre *pais_i) yline(0) level(95) ci recast(connected) offset(0) msize(1pt)    ///
	graphregion(color(white)) ///
	legend(rows(1)) ///
	yscale(range(-0.5 2)) ///
	subtitle("Other Departments")  ///
	title("Premium by year of schooling") ///
	b1title("Years of schooling") ///
	l1title("Schooling premium")
	graph export "$exp/schoolingpremiabyarea-Otherdep.png", replace


*****************************
*	Calculating rate Tertirary education 2000 and 2023  *
*****************************
cap erase "$exp/2.3Tertiaryeducation.xls"
foreach y of numlist 2009 2023{ 
u  "$data/SLV/SLV_`y'", replace
encode region_est2, gen(region)
*Total
tabout nivel [w=pondera] using "$exp/2.3Tertiaryeducation.xls", append
*By region
tabout nivel hombre [w=pondera] using "$exp/2.3Tertiaryeducation.xls", append
*By region
tabout region nivel  [w=pondera] using "$exp/2.3Tertiaryeducation.xls", append

}
*****************************
*	Calculating enrolment rate in secondary education 2000 and 2023  *
*****************************
*age 12-17 years old
cap erase "$exp/2.3secondaryenrollment.xls"
foreach y of numlist 2000 2023{ 
u  "$data/SLV/SLV_`y'", replace

*Total
tabout r203 if edad>=12 & edad<=17 [w=pondera] using "$exp/2.3secondaryenrollment.xls", append
*Urbano
tabout r203 if edad>=12 & edad<=17 & urbano==1 [w=pondera] using "$exp/2.3secondaryenrollment.xls", append
*Rural
tabout r203 if edad>=12 & edad<=17 & urbano==0 [w=pondera] using "$exp/2.3secondaryenrollment.xls", append
*Pobreza
tabout pobreza r203 if edad>=12 & edad<=17 & urbano==0 [w=pondera] using "$exp/2.3secondaryenrollment.xls", append

}
*****************************
*	Calculating attendance to early childhood education  *
*****************************
use SLV_2023, clear

tabout r201a [w=pondera] using "$exp/2.3earlychildhoodedu.xls", replace

use SLV_2015, clear

tabout r201a [w=pondera] using "$exp/2.3earlychildhoodedu.xls", append





*=========================================================================
*Chapter 3
*=========================================================================

use  "$data/SLV/SLV_2023", replace

*Agregar label a pobreza
label variable pobreza "Pobreza Nacional"
label define pobreza 0"No pobre"1 "Pobre extremo" 2 "Pobre relativo"
label values pobreza pobreza


*Using right incomes (not adjusted by rurality)
replace ila=ila*p_reg
replace ictap=ictap*p_reg
replace itranp=itranp*p_reg
replace itrane=itrane*p_reg
replace itranext_m=itranext_m*p_reg
replace itranint_m=itranint_m*p_reg
replace icap=icap*p_reg
replace ijubi=ijubi*p_reg
replace ijubi_ncon=ijubi_ncon*p_reg
replace ijubi_con=ijubi_con*p_reg
replace inla_otro=inla_otro*p_reg
replace inla=inla*p_reg


*Creating income variables at household level
egen ilaf=sum(ila), by(idboleta) //HH labor income
egen retirementcon=sum(ijubi_con), by(idboleta)
egen retirementnocon=sum(ijubi_ncon), by(idboleta)
egen retirement=sum(ijubi), by(idboleta)
egen pubtf=sum(itrane), by(idboleta)
egen pritf=sum(itranp), by(idboleta)
egen pridomf=sum(itranint_m), by(idboleta)
egen priextf=sum(itranext_m), by(idboleta)
egen capitalf=sum(icap), by(idboleta)
egen otrosf=sum(inla_otro), by(idboleta)

*Creating non-labor household income
egen ingnlg=rsum(pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1

*Creating household income
egen ingresof=rsum(ilaf pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1

*****************************
*	Labor and non-labor income by poverty status and area *
*****************************
local row=2

foreach y of numlist 0/1 { 
    foreach x of varlist ilaf ingnlg { 
        putexcel set "$exp/3.1HHlabornonlaborincome.xls", modify
       
        if `row' == 2 {
            putexcel A1=("Urban=1/Non-Urban=0") B1=("Total") C1=("Pobre extremo") D1=("Pobre relativo") E1=("No Pobre")
        }

        summ `x' [w=pondera] if r103==1 & urban==`y'
        putexcel A`row'=(`y') B`row'=(r(mean))
        
        summ `x' [w=pondera] if pobreza==1 & r103==1 & urban==`y'
        putexcel C`row'=(r(mean))
        
        summ `x' [w=pondera] if pobreza==2 & r103==1 & urban==`y'
        putexcel D`row'=(r(mean))
        
        summ `x' [w=pondera] if pobreza==0 & r103==1 & urban==`y'
        putexcel E`row'=(r(mean))

        local ++row 
    }
}	
	
/*
xtile [w=pondera] quintiles_urb=ingpe if urbano==1, nq(5)
xtile [w=pondera] quintiles_rur=ingpe if urbano==1, nq(5)

gen proportion_pritrans_urb=pritf/ingresof if urbano==1
gen proportion_pritrans_rur=pritf/ingresof if urbano==0

local row=8
foreach y of numlist 0/1 { 
  forvalues x=1/5 { 
        putexcel set "$exp/3.1HHlabornonlaborincome.xls", modify
        putexcel A7=("Quintiles") B7=("HH income") C7=("Private transfers") 
		putexcel A`row'=(`x')
		
		summ  proportion_pritrans_urb [w=pondera] if r103==1 & quintiles_urb==`x' 
		putexcel B`row'=(r(mean))

        local ++row 
    }	
	}
local row=14
foreach y of numlist 0/1 { 
  forvalues x=1/5 { 
        putexcel set "$exp/3.1HHlabornonlaborincome.xls", modify
        putexcel A13=("Quintiles") B13=("HH income") C13=("Private transfers") 
		putexcel A`row'=(`x')
		
		summ  proportion_pritrans_rur [w=pondera] if r103==1 & quintiles_rur==`x' 
		putexcel B`row'=(r(mean))

        local ++row 
    }	
	}
*/
*****************************
*	Percentage of HH receiving remittances and domestic transfers *
*****************************		
	
*Domestics transfers
gen dpt=1 if pridomf>0 & pridomf!=. 
replace dpt=0 if (pridomf==0 | pridomf==.)


*Remittances
gen ipt=1 if priextf>0 & priextf!=. 
replace ipt=0 if (priextf==0 | priextf==.) 

tabout dpt pobreza  [w=pondera] using "$exp/3.1Dom&remitrans.xls", replace
tabout ipt pobreza [w=pondera] using "$exp/3.1Dom&remitrans.xls", append

*****************************
*	Percentage of remittances and domestic transfers of non labor income in HH headed by woman *
*****************************		

local row=2
foreach x of numlist 1 0 {	
preserve
keep if urban==`x'  & r103==1	
putexcel set "$exp/3.1NonlaborincomebyheadofHH.xls", modify
putexcel A1=("Females") B1=("Domestic transfers") C1=("Remittances") D1=("Non-labor income")
sum pridomf [w=pondera] if  hombre==0
putexcel B`row'=(r(mean))
sum priextf [w=pondera] if  hombre==0 
putexcel C`row'=(r(mean))
sum ingnlg [w=pondera] if   hombre==0 
putexcel D`row'=(r(mean))

restore

local ++row
}

local row=6
foreach x of numlist 1 0 {	
preserve
keep if urban==`x'  & r103==1	
putexcel set "$exp/3.1NonlaborincomebyheadofHH.xls", modify
putexcel A5=("Males") B5=("Domestic transfers") C5=("Remittances") D5=("Non-labor income")
sum pridomf [w=pondera] if  hombre==1
putexcel B`row'=(r(mean))
sum priextf [w=pondera] if  hombre==1 
putexcel C`row'=(r(mean))
sum ingnlg [w=pondera] if   hombre==1 
putexcel D`row'=(r(mean))

restore

local ++row
}




*****************************
*	Percentage of HH receiving public transfers an HH share *
*****************************		
	
*Public transfers
gen pub=1 if pubtf>0 & pubtf!=. & r103==1
replace pub=0 if (pubtf==0 | pubtf==.) & r103==1
egen pubf=max(pub), by(idboleta)


local row=2
foreach x of numlist 1 2 0 {	
preserve
keep if urban==1  & r103==1
putexcel set "$exp/3.1Publictransfers.xls", modify
putexcel A1=("Females") B1=("Public transfers") C1=("Total income")
sum pubtf [w=pondera] if  pub==1 & pobreza==`x' 
putexcel B`row'=(r(mean))
sum ingresof [w=pondera] if   pub==1 & pobreza==`x' 
putexcel C`row'=(r(mean))

local ++row
restore
}

local row=6
foreach x of numlist 1 2 0 {	
preserve
keep if urban==0  & r103==1
putexcel set "$exp/3.1Publictransfers.xls", modify
sum pubtf [w=pondera] if  pub==1 & pobreza==`x' 
putexcel B`row'=(r(mean))
sum ingresof [w=pondera] if   pub==1 & pobreza==`x' 
putexcel C`row'=(r(mean))

local ++row
restore
}


*****************************
*	Percentage of HH receiving: Paquete agrícola, CSR, CSU. *
*****************************		
preserve
foreach x of numlist 2015 { 
u  "$data/SLV/SLV_`x'", replace 
tabout r325a8  [w=pondera] if urbano==0 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", replace clab("`x' Paquete agrícola")
tabout r325a3 [w=pondera] if urbano==0 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' CSU")
tabout r325a4 [w=pondera] if urbano==1 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' CRU")

gen csr=1 if r325a3==1 & urbano==0 & pobreza<=2
replace csr=0 if r325a3==2 & urbano==0 & pobreza<=2
tabstat csr [w=pondera] if r103==1, stats(mean)
}


foreach x of numlist 2016/2019  { 
u  "$data/SLV/SLV_`x'", replace 
tabout r321a8  [w=pondera] if urbano==0 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' Paquete agrícola")
tabout r321a3 [w=pondera] if urbano==0 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' CSU")
tabout r321a4 [w=pondera] if urbano==1 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' CRU")

}


foreach x of numlist 2021/2023 { 
u  "$data/SLV/SLV_`x'", replace 

tabout r319a8  [w=pondera] if urbano==0 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' Paquete agrícola")
tabout r319a3 [w=pondera] if urbano==0 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' CSU")
tabout r319a4 [w=pondera] if urbano==1 & pobre==1 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' CRU")

}
restore

u  "$data/SLV/SLV_2023", replace 
tabout pobreza r319a8  [w=pondera] if urbano==0 & r103==1 using "$exp/3.1Socialprotecprogrammes.xls", append clab("`x' Paquete agrícola")


*****************************
*	Percentage of HH receiving: PBU. *
*****************************		

foreach x of numlist 2015  { 
u  "$data/SLV/SLV_`x'", replace 
bysort id: egen max_edad = max(edad)
gen miembro_mayor_65 = max_edad > 65
tabout r325a5 [w=pondera] if pobre==1 & miembro_mayor_65==1 using "$exp/3.1Basicpension.xls", replace clab("`x' Paquete agrícola")

}


foreach x of numlist 2016/2019  { 
u  "$data/SLV/SLV_`x'", replace 

bysort id: egen max_edad = max(edad)
gen miembro_mayor_65 = max_edad > 65
tabout r321a5  [w=pondera] if miembro_mayor_65==1 & pobre==1 using "$exp/3.1Basicpension.xls", append clab("`x' Paquete agrícola")

}


foreach x of numlist 2021/2023 { 
u  "$data/SLV/SLV_`x'", replace 

bysort id: egen max_edad = max(edad)
gen miembro_mayor_65 = max_edad > 65
tabout r319a5  [w=pondera] if miembro_mayor_65==1 & pobre==1 using "$exp/3.1Basicpension.xls", append clab("`x' Paquete agrícola")
tabout r319a5  [w=pondera] if miembro_mayor_65==1 & pobreza==1 & urban==0 using "3.1Basicpension.xls", append clab("`x' Paquete agrícola")
tabout r319a5  [w=pondera] if miembro_mayor_65==1 & pobreza==1 & urban==0 using "3.1Basicpension.xls", append clab("`x' Paquete agrícola")

}

u  "$data/SLV/SLV_2023", replace 

bysort id: egen max_edad = max(edad)
gen miembro_mayor_65 = max_edad > 65

tabout r319a5  [w=pondera] if miembro_mayor_65==1 & pobreza==1 & urban==0 using "$exp/3.1Basicpension.xls", append clab("2023")
tabout r319a5  [w=pondera] if miembro_mayor_65==1 & pobreza==1 & urban==1 using "$exp/3.1Basicpension.xls", append clab("2023")


u  "$data/SLV/SLV_2019", replace 

bysort id: egen max_edad = max(edad)
gen miembro_mayor_65 = max_edad > 65

tabout r321a5  [w=pondera] if miembro_mayor_65==1 & pobreza==1 & urban==0 using "$exp/3.1Basicpension.xls", append clab("2019")
tabout r321a5  [w=pondera] if miembro_mayor_65==1 & pobreza==1 & urban==1 using "$exp/3.1Basicpension.xls", append clab("2019")



*****************************
*	Percentage of individuals receiving: contributory and non contributorypension. *
*****************************
u  "$data/SLV/SLV_2023", replace 

		
*Using right incomes (not adjusted by rurality)
replace ila=ila*p_reg
replace ictap=ictap*p_reg
replace itranp=itranp*p_reg
replace itrane=itrane*p_reg
replace itranext_m=itranext_m*p_reg
replace itranint_m=itranint_m*p_reg
replace icap=icap*p_reg
replace ijubi=ijubi*p_reg
replace ijubi_ncon=ijubi_ncon*p_reg
replace ijubi_con=ijubi_con*p_reg
replace inla_otro=inla_otro*p_reg
replace inla=inla*p_reg


*Creating income variables at household level
egen ilaf=sum(ila), by(idboleta)
egen retirementcon=sum(ijubi_con), by(idboleta)
egen retirementnocon=sum(ijubi_ncon), by(idboleta)
egen retirement=sum(ijubi), by(idboleta)
egen pubtf=sum(itrane), by(idboleta)
egen pritf=sum(itranp), by(idboleta)
egen pridomf=sum(itranint_m), by(idboleta)
egen priextf=sum(itranext_m), by(idboleta)
egen capitalf=sum(icap), by(idboleta)
egen otrosf=sum(inla_otro), by(idboleta)

* Contributory pensions
gen retcon=1 if retirementcon>0 & retirementcon!=. & r103==1
replace retcon=0 if (retirementcon==0 | retirementcon==.) & r103==1
egen retconf=max(retcon), by(idboleta)
tabstat retcon if edad>=60 [w=pondera], by(hombre)
tabstat retcon if edad>=60 & hombre==1 [w=pondera], by(pobreza)
tabstat retcon if edad>=60 & hombre==0 [w=pondera], by(pobreza)

*Non contributory pensions
gen retnocon=1 if retirementnocon>0 & retirementnocon!=. & r103==1
replace retnocon=0 if (retirementnocon==0 | retirementnocon==.) & r103==1
egen retnoconf=max(retnocon), by(idboleta)
tabstat retnocon if edad>=60 [w=pondera], by(pobreza)
tabstat retnocon if edad>=60 & hombre==1 [w=pondera], by(pobreza)
tabstat retnocon if edad>=60 & hombre==0 [w=pondera], by(pobreza)

*Creating non-labor household incom
egen ingnlg=rsum(pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1

tabout hombre retcon  [w=pondera] if edad>60  using "$exp/3.1ContributoryandnonPensions.xls", replace clab("Gender")
tabout hombre retnocon  [w=pondera] if edad>60 using "$exp/3.1ContributoryandnonPensions.xls", append clab("Gender")

tabout pobreza retcon  [w=pondera] if edad>60  using "$exp/3.1ContributoryandnonPensions.xls", append clab("Poverty")
tabout pobreza retnocon  [w=pondera] if edad>60 using "$exp/3.1ContributoryandnonPensions.xls", append clab("Poverty")

tabout pobreza using "$exp/3.1ContributoryandnonPensions.xls", append sum c(mean retirementnocon mean retirementcon mean ingnlg ) f(2) ///
    style(xlsx) clab("Promedio")

tabout pobreza using "$exp/3.1ContributoryandnonPensions.xls" if retnocon==1, append sum c(mean retirementnocon mean retirementcon mean ilaf ) f(2) ///
    style(xlsx) clab("Promedio")
tabout pobreza using "$exp/3.1ContributoryandnonPensions.xls" if retcon==1, append sum c(mean retirementnocon mean retirementcon mean ilaf ) f(2) ///
    style(xlsx) clab("Promedio")

	
*****************************
*	 HH receiving remittances: attendance to school by gender. *
*****************************	


*Domestics transfers
gen dpt=1 if pridomf>0 & pridomf!=. 
replace dpt=0 if (pridomf==0 | pridomf==.)


*Remittances
gen ipt=1 if priextf>0 & priextf!=. 
replace ipt=0 if (priextf==0 | priextf==.) 


gen asistek=1 if asiste==1 & edad>=4 & edad<=6
replace asistek=0 if asiste==0 & edad>=4 & edad<=6

tabout ipt asistek [w=pondera] if hombre==1 using "$exp/3.2Educationandremittances.xls", replace clab("H")
tabout ipt asistek [w=pondera] if hombre==0 using "$exp/3.2Educationandremittances.xls", append clab("M")

gen asistet=1 if asiste==1 & edad>=19 & edad<=24 
replace asistet=0 if asiste==0 & edad>=19 & edad<=24 

tabout ipt asistet [w=pondera] if hombre==1 using "$exp/3.2Educationandremittances.xls", append clab("H")
tabout ipt asistet [w=pondera] if hombre==0 using "$exp/3.2Educationandremittances.xls", append clab("M")

*****************************
*	 HH receiving remittances: participation rate *
*****************************	
tabout actpr2012 [w=pondera] if ipt==1 & hombre==0  using "$exp/3.2Labor&remittances.xls", replace clab("Gender")
tabout actpr2012 [w=pondera] if ipt==0 & hombre==0 using "$exp/3.2Labor&remittances.xls", append clab("Gender")

tabout actpr2012 [w=pondera] if ipt==1 & hombre==1  using "$exp/3.2Labor&remittances.xls", append clab("Gender")
tabout actpr2012 [w=pondera] if ipt==0 & hombre==1 using "$exp/3.2Labor&remittances.xls", append clab("Gender")

*****************************
*	 HH receiving remittances: labor: full time, formality and relation*
*****************************	
*Partial employment
gen under=1 if actse==2 | actse==3
replace under=0 if actse==1
*Formality
replace tipo_seguro=. if ocupado==0 | pea==0 | pea==.
gen formal=1 if tipo_seguro<=1 & ocupado==1
replace formal=0 if tipo_seguro==. & ocupado==1


tabout under ipt [w=pondera]  using "$exp/3.2Laborcharac&remittances.xls", replace 
tabout formal ipt [w=pondera]  using "$exp/3.2Laborcharac&remittances.xls", append 
tabout relab ipt [w=pondera] using "$exp/3.2Laborcharac&remittances.xls", append 

*****************************
*	 Elder receiving domestic transfers *
*****************************	

tab dpt [w=pondera] if edad>60
tab ipt [w=pondera] if edad>60
tabout ipt [w=pondera] if edad>60  using "$exp/3.2Elderpritrans.xls", replace clab("Gender")
tabout dpt [w=pondera] if edad>60 using "$exp/3.2Elderpritrans.xls", append clab("Gender")



*****************************
*	 School programs: EStudiantes colegio público: alimentos, uniforme y utiles escolares *
*****************************	
tab r210a [w=pondera]

tabout r210a [w=pondera] using "$exp/3.2Schoolprograms.xls", replace clab("School")

tabout r210a [w=pondera] if r210a==1 using "$exp/3.2Schoolprograms.xls", append clab("School")

*****************************
*	 HH receiving subsidies: Gas, electricity and water *
*****************************	

*Gas
tabout r319a1 pobreza if urbano==0 & r103==1 [w=pondera] using "$exp/3.2Subsidies.xls", replace 
tabout r319a1 pobreza if urbano==1 & r103==1 [w=pondera] using "$exp/3.2Subsidies.xls", append 

*Electricity
tabout r319a2 pobreza if urbano==0 & r103==1 [w=pondera] using "$exp/3.2Subsidies.xls", append 
tabout r319a2 pobreza if urbano==1 & r103==1 [w=pondera] using "$exp/3.2Subsidies.xls", append 


*Water
tabout r319a6 pobreza if urbano==0 & r103==1 [w=pondera] using "$exp/3.2Subsidies.xls", append 
tabout r319a6 pobreza if urbano==1 & r103==1 [w=pondera] using "$exp/3.2Subsidies.xls", append 



*=========================================================================
*Chapter 4
*=========================================================================
use  "$data/SLV/SLV_2023", replace
*****************************
*	 HH depdendent of agricultural labor income *
*****************************	

replace ila=ila*p_reg
egen ilaf=sum(ila), by(idboleta)

replace ingreso_agro=ingreso_agro*p_reg

egen ingagrof=max(ingreso_agro), by(id)

gen prop_agro=ingagrof/ilaf
replace prop_agro=0 if prop_agro==.

gen hogar_agro=0 if  r103==1
replace hogar_agro=1 if prop_agro>0.60  & r103==1


tabout hogar_agro if urbano==0 & r103==1 [w=pondera] using "$exp/4.1Agrolaborincomedependence.xls", replace 


*****************************
*	 HH severe food insecurity by region *
*****************************	
* Inseguridad alimentaria: 

* Recode variables r601 to r615 into x601 to x615
foreach var of numlist 601(1)615 {
     recode r`var' (1=1) (2=0), gen(x`var')
}

* Compute variable menor
gen menor = 0
replace menor = 1 if r106 < 18

* Sort cases by idboleta
sort id

* Aggregate to calculate menor_h
egen menor_h = max(menor), by(id)

* Compute variable privali
gen privali = 0

* Calcular privali dependiendo del valor de menor_h
egen privali_temp = rowtotal(x601 x602 x603 x604 x605 x606 x607 x608 x609 x610 x611 x612 x613 x614 x615) if menor_h==1

 egen privali_temp2 = rowtotal(x601 x602 x603 x604 x605 x606 x607 x608) if menor_h==0
 
* Compute variable privali

replace privali=privali_temp if menor_h==1
replace privali=privali_temp2 if menor_h==0

* Recode elcsa based on privali and menor_h
gen elcsa = .
replace elcsa = 1 if privali == 0
replace elcsa = 2 if privali >= 1 & privali <= 3 & menor_h == 0
replace elcsa = 3 if privali >= 4 & privali <= 6 & menor_h == 0
replace elcsa = 4 if privali >= 7 & privali <= 8 & menor_h == 0
replace elcsa = 2 if privali >= 1 & privali <= 5 & menor_h == 1
replace elcsa = 3 if privali >= 6 & privali <= 10 & menor_h == 1
replace elcsa = 4 if privali >= 11 & privali <= 15 & menor_h == 1

label def elcsa 1 "Security" 2 "Mild Insecurity" 3 "Moderate Insecurity" 4 "Severe Insecurity"
label val elcsa elcsa
label var elcsa "Food insecurity index"


gen inseguridad_alim_moderada= 0
replace inseguridad_alim_moderada = 1 if elcsa == 3
replace inseguridad_alim_moderada= . if r039 > 1 

gen inseguridad_alim_severa= 0
replace inseguridad_alim_severa = 1 if elcsa >= 4
replace inseguridad_alim_severa = . if r039 > 1 

encode region_est2, gen(region)
local row=2
forvalues x=1/14 {

putexcel set "$exp/4.2Moderatefoodinsec.xls", modify	
	putexcel A1=("región") B1=("`rate'") C1=("urban") D1=("rural")
	putexcel A`row'=region_est2 
	summ inseguridad_alim_moderada [w=pondera] if region==`x'
	putexcel B`row'=(r(mean))
	summ inseguridad_alim_moderada [w=pondera] if region==`x' & urban==1
	putexcel C`row'=(r(mean))	
	summ inseguridad_alim_moderada [w=pondera] if region==`x' & urbano==0
	putexcel D`row'=(r(mean))
local ++row
}

tabstat inseguridad_alim_severa [w=pondera] if urbano==0, stats (mean) by (region_est2)
tabstat inseguridad_alim_severa [w=pondera] if urbano==1, stats (mean) by (region_est2)


local row=2
forvalues x=1/14 {

putexcel set "$exp/4.2Severefoodinsec.xls", modify	
	putexcel A1=("región") B1=("`rate'") C1=("urban") D1=("rural")
	putexcel A`row'=region_est2 
	summ inseguridad_alim_severa [w=pondera] if region==`x'
	putexcel B`row'=(r(mean))
	summ inseguridad_alim_severa [w=pondera] if region==`x' & urban==1
	putexcel C`row'=(r(mean))	
	summ inseguridad_alim_severa [w=pondera] if region==`x' & urbano==0
	putexcel D`row'=(r(mean))
local ++row
}

tabstat inseguridad_alim_severa [w=pondera] if urbano==0, stats (mean) by (region_est2)
tabstat inseguridad_alim_severa [w=pondera] if urbano==1, stats (mean) by (region_est2)

*****************************
*	 HH perception about food availability *
*****************************	
cap erase "$exp/4.2Perceptionaboutfood.xls"
foreach x of numlist 601/615 {
tabout pobreza x`x' [w=pondera] using "$exp/4.2Perceptionaboutfood.xls", append clab("n")
}


