**********************************************************************
*El Salvador Poverty and Equity Assessment 2024
**********************************************************************
*Do file: Appendix
*Last update: 26/11/2024
**********************************************************************

*	Figure A.1 Trends in poverty lines
*****************************
 

	
local row=3
foreach y of numlist 2000(1)2023{ 
u  "$data/SLV/SLV_`y'", replace
cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion) 

gen ipcf_ppp17=ipcf*factor_ppp17

gen lp_685usd_ppp = (6.85 * 365/12)
gen lp_215usd_ppp = (2.15 * 365/12)

gen pobre_215=0
replace pobre_215=1 if ipcf_ppp17< lp_215usd_ppp

gen pobre_685=0
replace pobre_685=1 if ipcf_ppp17< lp_685usd_ppp

	putexcel set "$tabs/FigureA1.xls", modify	
	putexcel B1=("Low Income") D1=("Middle Income") F1=("Official Poverty") H1=("Official Extreme Poverty")
	putexcel A`row'=("`y'")
	summ pobre_215 [w=pondera] if urbano==1
	putexcel B`row'=(r(mean)*100) 
	summ pobre_215 [w=pondera] if urbano==0
	putexcel C`row'=(r(mean)*100) 
	
	summ pobre_685 [w=pondera] if urbano==1
	putexcel D`row'=(r(mean)*100) 
	summ pobre_685 [w=pondera] if urbano==0
	putexcel E`row'=(r(mean)*100) 
	
	summ pobre [w=pondera] if urbano==1
	putexcel F`row'=(r(mean)*100) 
	summ pobre [w=pondera] if urbano==0
	putexcel G`row'=(r(mean)*100) 
	
	summ pobreext [w=pondera] if urbano==1
	putexcel H`row'=(r(mean)*100) 
	summ pobreext [w=pondera] if urbano==0
	putexcel I`row'=(r(mean)*100) 
	
	
	local ++row	
}





*Figure A.2 Poverty line growth and distribution decomposition
*****************************

u  "$data/SLV/SLV_2021", replace //Cambiar años
append using "$data/SLV/SLV_2023.dta", force

preserve 

keep if urbano==1 

cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion) 


*Linea de pobreza nacional
gen ingpe_ppp17=ingpe*factor_ppp17
gen lp_moderada_ppp17=lp_moderada*factor_ppp17

skdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_moderada_ppp17)

return list

putexcel set "$tabs/FigureA2.xls", modify	
	
	putexcel A1=("Urbano -  Official poverty")
	putexcel E1=("Urbano -  Middle income")
	putexcel A2=("Growth")
	putexcel A3=("Redistribution")
	putexcel A4=("Line")
	putexcel A5=("Total")
	putexcel B2=matrix(r(b))
 

*Linea de pobreza nacional
gen ipcf_ppp17=ipcf*factor_ppp17
gen lp_685usd_ppp = (6.85 * 365/12)

skdecomp ipcf_ppp17 [w = pondera] if ipcf_ppp17>0 , by(ano) varpl(lp_685usd_ppp) 


return list

putexcel set "$tabs/FigureA2.xls", modify	

	putexcel E2=matrix(r(b))
	
restore 


preserve 

keep if urbano==0 

cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion) 


*Linea de pobreza nacional
gen ingpe_ppp17=ingpe*factor_ppp17
gen lp_moderada_ppp17=lp_moderada*factor_ppp17

skdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_moderada_ppp17)
return list 

putexcel set "$tabs/FigureA2.xls", modify	
	putexcel A8=("Rural -  Official poverty")
	putexcel E8=("Rural - Middle income ")
	putexcel A9=("Growth")
	putexcel A10=("Redistribution")
	putexcel A11=("Line")
	putexcel A12=("Total")
	putexcel B9=matrix(r(b))
*Linea de pobreza nacional
gen ipcf_ppp17=ipcf*factor_ppp17
gen lp_685usd_ppp = (6.85 * 365/12)

skdecomp ipcf_ppp17 [w = pondera] if ipcf_ppp17>0 , by(ano) varpl(lp_685usd_ppp) 

return list 

putexcel set "$tabs/FigureA2.xls", modify
	putexcel E9=matrix(r(b))
	
restore 
