**********************************************************************
*El Salvador Poverty and Equity Assessment 2024
**********************************************************************
*Do file: Figures & Tables Chapter 1
*Last update: 26/11/2024
**********************************************************************


*	Figure 2. Trends in poverty headcount and official poverty lines, 2000–2023 *
*****************************
 

	
local row=2
foreach y of numlist 2000(1)2023{ 
u  "$data/SLV/SLV_`y'", replace
gen pop=1 if id!=.

	putexcel set "$tabs/Figure2.xls", modify	
	putexcel B1=("Poverty") C1=("Extreme poverty")
	putexcel A`row'=("`y'")
	summ pobre [w=pondera] 
	putexcel B`row'=(r(mean)*100)
	summ pobreext [w=pondera] 
	putexcel C`row'=(r(mean)*100)
	
	local ++row	
}


*	Figure 4. Growth-distribution decomposition of official poverty changes (2000–2023) *
*****************************

*Interval 1: 2000-2009

u  "$data/SLV/SLV_2000", replace
append using "$data/SLV/SLV_2009.dta", force

capture drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion) 

gen ingpe_ppp17=ingpe*factor_ppp17
gen lp_modera_ppp17=lp_moderada*factor_ppp17
preserve
keep if urbano==0
drdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_modera_ppp17) 
matrix result1 = r(b)
putexcel set "$tabs/Figure4.xls", sheet("2000-09 rural") modify 
putexcel A1=matrix(result1)
restore
preserve
keep if urbano==1
drdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_modera_ppp17) 
matrix result2 = r(b)
putexcel set "$tabs/Figure4.xls", sheet("2000-09 urbano") modify 
putexcel A1=matrix(result2)

restore

*Interval 2: 2009-2019

u  "$data/SLV/SLV_2009", replace 
append using "$data/SLV/SLV_2019.dta", force

capture drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion) 

gen ingpe_ppp17=ingpe*factor_ppp17
gen lp_modera_ppp17=lp_moderada*factor_ppp17
preserve
keep if urbano==0
drdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_modera_ppp17) 
matrix result3 = r(b)
putexcel set "$tabs/Figure4.xls", sheet("2009-19 rural") modify 
putexcel A1=matrix(result3)

restore
preserve
keep if urbano==1
drdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_modera_ppp17) 
matrix result4 = r(b)
putexcel set "$tabs/Figure4.xls", sheet("2009-19 urbano") modify 
putexcel A1=matrix(result4)

restore

*Interval 3: 2019-2023

u  "$data/SLV/SLV_2019", replace
append using "$data/SLV/SLV_2023.dta", force


capture drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion) 

gen ingpe_ppp17=ingpe*factor_ppp17
gen lp_modera_ppp17=lp_moderada*factor_ppp17
preserve
keep if urbano==0
drdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_modera_ppp17) 
matrix result5 = r(b)
putexcel set "$tabs/Figure4.xls", sheet("2019-23 rural") modify 
putexcel A1=matrix(result5)

restore
preserve
keep if urbano==1
drdecomp ingpe_ppp17 [w = pondera], by(ano) varpl(lp_modera_ppp17) 
matrix result6 = r(b)
putexcel set "$tabs/Figure4.xls", sheet("2019-23 urbano") modify 
putexcel A1=matrix(result6)

restore


*	Figure 5. Growth incidence curve, 2000, 2009, 2019, and 2023*
*****************************

foreach x of numlist 2000 2009 2019 2023 { 
u  "$data/SLV/SLV_`x'", replace 
replace ingpe= ingpe*8.75 if ano==2000
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
drop if _merge==2

gen factor_ppp17nacional=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion) 
gen double ingpe_ppp17=ingpe*factor_ppp17nacional

gen daily_ingpe_ppp= ingpe_ppp17/30.42
su daily_ingpe_ppp [w=pondera]

xtile [w=pondera] peringpe_urb=ingpe_ppp17 if urbano==1, nq(100)
xtile [w=pondera] peringpe_rur=ingpe_ppp17 if urbano==0, nq(100)

sort urban
by urban: su daily_ingpe_ppp [w=pondera]
sum daily_ingpe_ppp [w=pondera] if urbano==1
gen mean_urb=r(mean)
sum daily_ingpe_ppp [w=pondera] if urbano==0
gen mean_rur=r(mean)


preserve 
collapse (mean) ingpe_ppp17 mean_urb [w=pondera], by(peringpe_urb)
egen totincome=total(ingpe_ppp17)
gen deciles=ingpe_ppp17/totincome
keep peringpe_urb deciles mean_urb
export excel using "$tabs/Figure5_urbano`x'.xls", firstrow(variables) replace
restore

preserve 
collapse (mean) ingpe_ppp17 mean_rur [w=pondera], by(peringpe_rur)
egen totincome=total(ingpe_ppp17)
gen deciles=ingpe_ppp17/totincome
keep peringpe_rur deciles mean_rur
export excel using "$tabs/Figure5_rural`x'.xls", firstrow(variables) replace
restore

}

*	Figure 6. Sources of real monthly income (PPP 2017) for poorest households, 2019–2023*
*****************************

foreach x of numlist 2019 2021 2022 2023{ 
	u  "$data/SLV/SLV_`x'", replace 
cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)
gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion)

****Percentiles of hh income (ppp 2017)

gen double ingpe_ppp17=ingpe*factor_ppp17

xtile [w=pondera] peringpe_urb=ingpe_ppp17 if urbano==1, nq(100)
xtile [w=pondera] peringpe_rur=ingpe_ppp17 if urbano==0, nq(100)

xtile [w=pondera] decingpe_urb=ingpe_ppp17 if urbano==1, nq(10)
xtile [w=pondera] decingpe_rur=ingpe_ppp17 if urbano==0, nq(10)

***Removing rural deflactor

replace ila=ila*p_reg
replace itranp=itranp*p_reg
replace itrane=itrane*p_reg
replace itranext_m=itranext_m*p_reg
replace itranint_m=itranint_m*p_reg
replace icap=icap*p_reg
replace ijubi=ijubi*p_reg
replace ijubi_ncon=ijubi_ncon*p_reg
replace ijubi_con=ijubi_con*p_reg
replace inla_otro=inla_otro*p_reg
replace inla=inla*p_reg

***Labor and Non-labor income in ppp 2017
	
foreach incomevar in ila inla  itrane ijubi icap itranext_m itranint_m inla_otro{
cap drop `incomevar'_ppp17
qui gen `incomevar'_ppp17=`incomevar'*factor_ppp17
				}
	
***Labor hh income
egen h_ila=sum(ila_ppp17), by(idboleta)

***Non-labor hh income
egen h_inla=sum(inla_ppp17), by(idboleta)

*Export results

preserve 
collapse (mean) h_ila h_inla [w=pondera], by(peringpe_urb)

export excel using "$tabs/Figure6_urbano`x'.xls", firstrow(variables) replace
restore

preserve 
collapse (mean) h_ila h_inla  [w=pondera], by(peringpe_rur)

export excel using "$tabs/Figure6_rural`x'.xls", firstrow(variables) replace
restore

}

*	Figure 7. Gender gap in official poverty, by age, 2000 and 2023*
*****************************
foreach y of numlist 2000 2023{ 
	
	u  "$data/SLV/SLV_`y'", replace
recode edad (0/4=1) (5/9=2) (10/14=3) (15/19=4) (20/24=5) (25/29=6) (30/34=7) (35/39=8) (40/44=9) (45/49=10) (50/54=11) (55/59=12) (60/64=13) (65/69=14) (70/74=15) (75/max=16), gen (cat5)

local row=2
foreach x of numlist 1/16{ 

	putexcel set "$tabs/Figure7_`y'.xls", modify	
	putexcel B1=("Mujeres") C1=("Hombres") 
	putexcel A`row'=("`x'")
	sum pobre [w=pondera] if hombre==0 & cat5==`x'
	putexcel B`row'=(r(mean))
	sum pobre [w=pondera] if hombre==1 & cat5==`x'
	putexcel C`row'=(r(mean))
	
	local ++row
	
	}

}

*	Figure 9.  Inequality evolution, Latin America, 2000–2023*
*****************************

local row=2
foreach x of numlist 2000(1)2019 2021 2022 2023{ 
	u  "$data/SLV/SLV_`x'", replace 
	
cap drop ipc17_sedlac ipc_sedlac ppp17 conversion
cap drop _merge
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)

gen factor_ppp17=(ipc17_sedlac/ipc_sedlac)/(ppp17*conversion)
gen double ipcf_ppp17=ipcf*factor_ppp17

	dis "gini `x'"
	putexcel set "$tabs/Figure9.xls", modify	
	putexcel B1=("Gini index")  
	putexcel A`row'=("`x'")
	ainequal ipcf_ppp17 [w=pondera]
	putexcel B`row'=(r(gini_1))
	
	local ++row
	
	}

*	Table 1.  Multidimensional poverty: deprivations and gaps (2023)*
*****************************

*********************************************************************
*Pobreza multidimensional
*********************************************************************
u  "$data/SLV/SLV_2023", replace 

*1. Education

*1.1 Scholl non-attendance
gen iden=0
replace iden=1 if (edad>=4 & edad<=17)
replace iden=0 if r103==10
replace iden=0 if r103otr==10
gen inasistencia=0 
replace inasistencia=1 if r212==2 & iden==1
replace inasistencia=1 if r214==8 & iden==1
replace inasistencia=1 if r214<=3 & r215<=10 & iden==1
drop iden
bysort id: egen inasistenciax=sum(inasistencia), missing
replace inasistenciax=0 if missing(inasistenciax)
gen inasistencia_hog=(inasistenciax>=1)


*1.2 School backwardness
gen iden=0
replace iden=1 if r106>=10 & r106<=17
replace iden=0 if r103==10
replace iden=0 if r103otr==3

gen rezago=0 
replace rezago=1 if iden==1 & r204<2 
replace rezago=1 if iden==1 & r204==2 & (r106-r204g)>=9
drop iden

bysort id: egen rezagox=sum(rezago)
replace rezagox=0 if missing(rezagox)
gen rezago_hog=(rezagox>=1)

*1.3 Early care
gen asiste_eduinicial=1 if r201a==2 & (edad>=1 & edad<=3)
replace asiste_eduinicial=0 if r201a==1 & (edad>=1 & edad<=3)
bysort id: egen asiste_eduinicialx=sum(asiste_eduinicial), missing
replace asiste_eduinicialx=0 if missing(asiste_eduinicialx)
gen asiste_eduinicial_hog=(asiste_eduinicialx>=1)

*1.4 Low adult education
gen iden=0
replace iden=1 if r106>=18
replace iden=0 if r103==10
replace iden=0 if r103otr==3

gen baja_edu=0 
replace baja_edu=1 if r212==2  & iden==1
replace baja_edu=1 if r106>64 & (r214==0 | r214==2 | r214==3 | r214==8) & (r215<6 | r215==.) & iden==1
replace baja_edu=1 if r106>64 & r204<3 & r204g<6 & iden==1
replace baja_edu=1 if r106<=64 & (r214==0 | r214==1 | r214==2 | r214==3 | r214==8 ) & (r217==1 | r219==.) & iden==1
replace baja_edu=1 if r106<=64 & r204<=3 & r204g<=10 & iden==1
drop iden

bysort id: egen baja_edux=sum(baja_edu), missing
replace baja_edux=0 if missing(baja_edux)
gen baja_edu_hog=(baja_edux>=1)

*2. Housing

*2.1 Inadequate roof
gen roof=0
replace roof=1 if r302b==2
replace roof=1 if r302==5 | r302==6 | r302==7

*2.2 Inadequate floor and wall
gen wall_floor=0
replace wall_floor=1 if r304==5
replace wall_floor=1 if r303b==2 | (r303==5 | r303==4 | r303==6 | r303==7 | r303==8)

*2.3 Overcrowding
gen haci=miembros/dormi
gen hacinado=0
replace hacinado=1 if haci>=3

*2.4 Land tenure
replace r308=5.1 if r308==5
gen tenencia=0
replace tenencia=1 if r308==7 | r308==6 | r308==5.1 | r308==5 | r308==4


*3. Work

*3.1 Underemployment

gen iden= 0
replace iden= 1 if r106>= 16 & actpr<30
replace iden= 0 if r103==10
replace iden= 0 if r103otr==3

recode r416 (111/333=1) (510/1200=2) (1511/4390=2) (5811/5920=2) ///
             (1311/1430=3) (4510/5630=4) (6010/9900=4), gen(ocup)

replace ocup=. if ocup>4
gen sala_min = 0
* Minimum wage
replace sala_min = 243.46 if ocup == 1
replace sala_min = 365 if ocup == 2
replace sala_min = 359.16 if ocup == 3
replace sala_min = 365 if ocup == 4

* 1 - Agropecuario.
* 2 - Industria.
* 3 - Maquila textil y confecci�n.
* 4 - Comercio y servicios.


gen subempleo = 0
replace subempleo = 1 if iden == 1 & inlist(r413, 2, 3)
replace subempleo = 1 if iden == 1 & actpr == 10 & r413a>0 & r413a!=. & money<sala_min
replace subempleo = 1 if iden == 1 & actpr == 10 & r418a == 1
replace subempleo = 1 if iden == 1 & r444 == 1 & r445 >2 & r445!=.

drop iden
bysort id: egen subempleo_hog= max(subempleo)

*3.2 Unemployment
gen iden=0
replace iden=1 if r106>=16 & actpr<30
replace iden=0 if r103==10
replace iden=0 if r103otr==10

gen desempleo=0
replace desempleo=1 if actpr>10 & actpr<30 & iden==1
replace desempleo=1 if (r446==4 | r446==5) & actpr==10 & iden==1
drop iden 

bysort id: egen desempleox=sum(desempleo), missing
replace desempleox=0 if missing(desempleox)
gen desempleo_hog=(desempleox>=1)

*3.3 Social security
gen iden=0
replace iden=1 if r106>=16 & actpr==10
replace iden=0 if r103==10
replace iden=0 if r103otr==3
gen seguridad_social=0
*1. EAP without health insurance
replace seguridad_social=1 if r501==8 & iden==1
*2. EAP without access to pensions
replace seguridad_social=1 if (r422c==1 | r422c==3) & (r422f==1 | r422f==3) & (r422g==1 | r422g==3) & iden==1
drop iden

bysort id: egen seguridad_socialx=sum(seguridad_social), missing
replace seguridad_socialx=0 if missing(seguridad_socialx)
gen seguridad_social_hog=(seguridad_socialx>=1)

*3.4 Child work
gen iden=0 
replace iden=1 if r106<18
replace iden=0 if r103==10
replace iden=0 if r103otr==3

recode r416 (100/299=1)(300/399=2)(500/999=3)(1000/3399=4) ///
(3500/3999=5)(4100/4399=6)(4500/4799=7)(5500/5699=7) ///
(4900/5399=8)(5900/6399=8)(6400/8299=9)(8400/8439=10) ///
(8500/8599=11)(8600/9699=12)(9700/9899=13), gen (rama1)
label variable rama1 "Rama"

gen rama2=rama1
replace rama2=1 if inlist(rama1, 1, 2, 3)
replace rama2=14 if inlist(rama1, 5, 6, 8, 9, 10, 11, 12)


gen ti_rama=1 if r106>=5 & r106<=17 & inlist(r416,510,520,610,620,710,721, ///
729,810,891,892,893,899,910,1010,1910,1920,2011,2012,2021,2022,2029,2310,2391,2392, ///
2393,2394,2395,2396,2399,2410,2420,2520,2660,2720,3520,3811,3812,3821,3822,3830,3900, ///
4620,4661,4690,4730,4773,5222,5224,5229,5510,5590,5914,9602,9609,9700) 

gen ti_ho_sema=h411a if r106>=5 & r106<=17 
gen ti_dias_sema=d411b if r106>=5 & r106<=17
replace ti_ho_sema=h412a if r106>=5 & r106<=17 & ti_ho_sema==0
replace ti_dias_sema=d412b if r106>=5 & r106<=17 & ti_dias_sema==0



gen t1=r411c if r106>=5 & r106<=17 & actpr==10 
gen t11=r411f if r106>=5 & r106<=17 & actpr==10 
gen t2=r412c if r106>=5 & r106<=17 & actpr==10 
gen t22=r412f if r106>=5 & r106<=17 & actpr==10


replace t1=0 if r106>=5 & r106<=17 & actpr==10 & missing(t1)
replace t11=0 if r106>=5 & r106<=17 & actpr==10 & missing(t11)
replace t2=0 if r106>=5 & r106<=17 & actpr==10 & missing(t2)
replace t22=0 if r106>=5 & r106<=17 & actpr==10 & missing(t22)

gen jornada=t1*10+t11 if r411a>=0 & ti_ho_sema>0 & r106>=5 & r106<=17 
replace jornada=t1*10+t11 if missing(r411a) & r411d>=1 & ti_ho_sema>0 & r106>=5 & r106<=17
replace jornada=t2*10+t22 if missing(r411a) & missing(r411d) & ti_ho_sema>0 & r106>=5 & r106<=17

gen turno=jornada
replace turno=1 if jornada==10 | jornada==11
replace turno=2 if jornada==2 | jornada==3
replace turno=2 if jornada>=12 & jornada<=33

label define turno 1"Diurno" 2"Nocturno o mixto"
label variable turno "Turno"
label values turno turno

gen horas_dia=ti_ho_sema/ti_dias_sema

gen ti_rama15=1 if r106>=5 & r106<=15 & inlist(r416,510,520,610,620,710,721,729,810,891,892, ///
893,899,910,1010,1910,1920,2011,2012,2021,2022,2029,2310,2392,2393,2394,2395,2396, ///
2399,2410,2420,2520,2660,2720,3520,3811,3812,3821,3822,3830,3900,4620,4661,4690, ///
4730,4773,5222,5224,5229,5510,5590,5914,9602,9609,9700)

gen ti_rama16=1 if r106==16 & inlist(r416, 510,520,610,620,710,721,729,810,891,892, ///
893,899,910,1010,1910,1920,2011,2012,2021,2022,2029,2310,2392,2393,2394,2395,2396, ///
2399,2410,2420,2520,2660,2720,3520,3811,3812,3821,3822,3830,3900,4620,4661,4690, ///
4730,4773,5222,5224,5229,5510,5590,5914,9602,9609,9700)

gen ti_rama17=1 if r106==17 & inlist(r416,510,520,610,620,710,721,729,810,891,892, ///
893,899,910,1010,1910,1920,2011,2012,2021,2022,2029,2310,2392,2393,2394,2395,2396, ///
2399,2410,2420,2520,2660,2720,3520,3811,3812,3821,3822,3830,3900,4620,4661,4690, ///
4730,4773,5222,5224,5229,5510,5590,5914,9602,9609)

replace ti_rama15=0 if r106>=5 & r106<=17 & actpr==10 & missing(ti_rama15)
replace ti_rama16=0 if r106>=5 & r106<=17 & actpr==10 & missing(ti_rama16)
replace ti_rama17=0 if r106>=5 & r106<=17 & actpr==10 & missing(ti_rama17)


gen sum_ciiu=ti_rama15+ti_rama16+ti_rama17

gen ti_ocupa=1 if edicion<=2012 & r106>=5 & r106<=17 & sum_ciiu==0 & inlist(r414,110,210,310, ///
2652,2653,3122,3123,3434,5112,5120,5163,5164,5212,5322,5329,5411,5412,5413,5414, ///
5419,6222,6223,6224,7111,7112,7113,7114,7115,7119,7121,7123,7124,7125,7126,7127, ///
7211,7212,7213,7214,7215,7221,7223,7224,7231,7232,7233,7234,7315,7317,7319,7321, ///
7322,7411,7412,7413,7421,7422,7511,7512,7521,7522,7523,7531,7532,7533,7534,7535, ///
7536,7541,7542,7549,8132,8155,8160,8172,8182,8311,8312,8321,8322,8331,8332,8341, ///
8342,8343,8344,9122,9123,9129,9216,9311,9312,9313,9331,9332,9333,9334,9411,9520, ///
9611,9612,9613,9621,9622,9624,9629)
replace ti_ocupa=1 if edicion>=2013 & r106>=5 & r106<=17 & sum_ciiu==0 & inlist(r414,110,210,310, ///
2652,2653,3122,3123,3434,5112,5120,5163,5164,5212,5322,5329,5411,5412,5413,5414, ///
5419,6222,6223,6224,7111,7112,7113,7114,7115,7119,7121,7123,7124,7125,7126,7127, ///
7211,7212,7213,7214,7215,7221,7223,7224,7231,7232,7233,7234,7315,7317,7319,7321, ///
7322,7411,7412,7413,7421,7422,7511,7512,7521,7522,7523,7531,7532,7533,7534,7535, ///
7536,7541,7542,7549,8132,8155,8160,8172,8182,8311,8312,8321,8322,8331,8332,8341, ///
8342,8343,8344,9122,9123,9129,9216,9311,9312,9313,9331,9332,9333,9334,9411,9520, ///
9611,9612,9613,9621,9622,9624,9629)


gen ti_riesgo1=1 if edicion<=2012 & r106>=5 & r106<=17 & sum_ciiu==0 & inlist(r414,3474,6111, ///
6112,6113,6114,6130,6141,6210,9211,9212) & (r417a01==1 | r417a02==1 | r417a03==1 | r417a04==1 | r417a10==1)

replace ti_riesgo1=1 if edicion>=2013 & r106>=5 & r106<=17 & sum_ciiu==0 & inlist(r414,2659,6111, ///
6112,6113,6114,6130,6210,6310,6320,6330,6340,9211,9212,9213,9214,9215) & ///
(r417a01==1 | r417a02==1 | r417a03==1 | r417a04==1 | r417a10==1)

gen tp1=1 if r106>=5 & r106<=15 & (ti_rama15==1 | ti_ocupa==1 | ti_riesgo1==1)
replace tp1=1 if r106==16 & (ti_rama16==1 | ti_ocupa==1 | ti_riesgo1==1) 
replace tp1=1 if r106==17 & (ti_rama17==1 | ti_ocupa==1 | ti_riesgo1==1)
replace tp1=0 if r106>=5 & r106<=17 & actpr==10 & missing(tp1)

gen jornaexceso=1 if tp1==0 & r106>=5 & r106<=17 & turno==2
replace jornaexceso=1 if tp1==0 & r106>=5 & r106<=15 & (horas_dia>6 | ti_ho_sema>34) & turno==1
replace jornaexceso=1 if tp1==0 & r106>=16 & r106<=17 & (horas_dia>8 | ti_ho_sema>44) & turno==1
replace jornaexceso=0 if tp1>=0 & missing(jornaexceso)

gen tp_fin=tp1+jornaexceso


gen trabajo_infantil=0 if r106>=5 & r106<=17 & actpr>10
replace trabajo_infantil=1 if r106>=5 & r106<=13 & actpr==10
replace trabajo_infantil=1 if r106>=14 & r106<=17 & tp_fin==1
replace trabajo_infantil=2 if r106>=14 & r106<=17 & tp_fin==0

label variable trabajo_infantil "Trabajo infantil"
label define trabajo_infantil 0 "No trabaja" 1 "Trabajo infantil" 2 "Trabajo permitido"
label values trabajo_infantil trabajo_infantil

gen trabajo_fin=0 if r106>=5 & r106<=17 & actpr>10
replace trabajo_fin=1 if r106>=5 & r106<=13 & actpr==10 & ((rama1>=1 & rama1<=12) | rama1==14)
replace trabajo_fin=1 if r106>=5 & r106<=16 & actpr==10 & rama1==13
replace trabajo_fin=2 if r106>=14 & r106<=17 & ((rama1>=1 & rama1<=12) | rama1==14) & tp_fin==1
replace trabajo_fin=2 if r106==17 & rama1==13 & tp_fin==1
replace trabajo_fin=3 if r106>=14 & r106<=17 & tp_fin==0

label variable trabajo_fin "Trabajo infantil detallado"
label define trabajo_fin 0 "No trabaja" 1 "Trabajo infantil por debajo de la edad mínima" 2 "Trabajo infantil peligroso" 3 "Trabajo permitido"
label values trabajo_fin trabajo_fin

gen trab_inf=0
replace trab_inf=1 if iden==1 & inlist(trabajo_fin,1,2)

replace trab_inf=1 if iden==1 & r106>=5 & r106<=13 & (r447fh1+r447fh2+r447fh3+ ///
r447fh4+r447fh5+(r447fm1+r447fm2+r447fm3+r447fm4+r447fm5)/60)>=28


bysort idboleta: egen trab_inf_hog = max(trab_inf)

tab trab_inf_hog [w=pondera] if jefe==1


*4. Health, services and food insecurity

*4.1 Health services

sort id 
by id: egen nadie_enfermo = min(r501)

gen salud = 0
replace salud = 1 if r503 >= 4 & inlist(r508, 1, 2, 3, 4, 5, 7, 9, 10, 11, 12)
replace salud = 1 if inlist(r504, 8, 9, 10, 11) & inlist(r508, 1, 2, 3, 4, 5, 7, 9, 10, 11, 12)
replace salud = 1 if r504 == 7 & inlist(r508, 1, 2, 3, 4, 5, 7, 9, 10, 11, 12)
replace salud = 1 if inlist(r509, 8, 9, 10, 11) & inlist(r510, 1, 2, 3, 4, 5, 7, 9, 10, 11) & nadie_enfermo == 5
replace salud = 1 if r509 == 7 & inlist(r510, 1, 2, 3, 4, 5, 7, 9, 10, 11) & nadie_enfermo == 5

bysort id: egen salud_hog=max(salud)

*4.2 Water
gen aguapot=0
replace aguapot=1 if r312>=5 & r312<=6

*4.3 Sanitation
gen sani=0
replace sani=1 if r315==2 | (sanitation_source>=4 & sanitation_source<=13)

*4.5 Food insecurity 

foreach var of numlist 601(1)615 {
     recode r`var' (1=1) (2=0), gen(x`var')
}

gen menor = 0
replace menor = 1 if r106 < 18

* Sort cases by idboleta
sort id

* Aggregate to calculate menor_h
egen menor_h = max(menor), by(id)

* Compute variable privali
gen privali = 0

* Calcular privali depends of the value of  menor_h
egen privali_temp = rowtotal(x601 x602 x603 x604 x605 x606 x607 x608 x609 x610 x611 x612 x613 x614 x615) if menor_h==1

 egen privali_temp2 = rowtotal(x601 x602 x603 x604 x605 x606 x607 x608) if menor_h==0
 
* Compute variable privali

replace privali=privali_temp if menor_h==1
replace privali=privali_temp2 if menor_h==0

* Recode elcsa based on privali and menor_h
gen elcsa = .
replace elcsa = 1 if privali == 0
replace elcsa = 2 if privali >= 1 & privali <= 3 & menor_h == 0
replace elcsa = 3 if privali >= 4 & privali <= 6 & menor_h == 0
replace elcsa = 4 if privali >= 7 & privali <= 8 & menor_h == 0
replace elcsa = 2 if privali >= 1 & privali <= 5 & menor_h == 1
replace elcsa = 3 if privali >= 6 & privali <= 10 & menor_h == 1
replace elcsa = 4 if privali >= 11 & privali <= 15 & menor_h == 1

label def elcsa 1 "Security" 2 "Mild Insecurity" 3 "Moderate Insecurity" 4 "Severe Insecurity"
label val elcsa elcsa
label var elcsa "Food insecurity index"

* Compute 
gen inseguridad_alim= 0
replace inseguridad_alim = 1 if elcsa >= 3
replace inseguridad_alim = . if r039 > 1 


*5. Habitat quality

*5.1 Recreation

gen esp1=1 if r616_01 == 2 | (r616_01 == 1 & r617_01 == 2 & inlist(r618_01, 6, 7))
gen esp2=1 if r616_02 == 2 | (r616_02 == 1 & r617_02 == 2 & inlist(r618_02, 6, 7))
gen esp3=1 if r616_03 == 2 | (r616_03 == 1 & r617_03 == 2 & inlist(r618_03, 6, 7))
gen esp4=1 if r616_04 == 2 | (r616_04 == 1 & r617_04 == 2 & inlist(r618_04, 6, 7))


gen esparcimiento=0
replace esparcimiento=1 if esp1==1 & esp2==1 & esp3==1 & esp4==1
replace esparcimiento= . if contro616 > 1

tab esparcimiento [w=pondera] if jefe==1

*5.2 Crime 
gen crimen=0 if r619_1!=. & r619_2!=. & r619_3!=. & r619_4!=. & r619_5!=. & r619_6!=. & r619_7!=. & r619_8!=. & r619_9!=. & r619_10!=. & r619_11!=.
replace crimen=1 if r619_1==1 | r619_2==1 | r619_3==1 | r619_4==1 | r619_5==1 |r619_6==1| r619_7==1| r619_8==1 | r619_9==1|r619_10==1 | r619_11==1

*5.3 Insecurity
gen inseguridad=0 if r620_1!=. & r620_2!=. & r620_3!=. & r620_4!=.  | r620_5!=.
replace inseguridad=1 if r620_1==2 | r620_2==2 | r620_3==2 | r620_4==2  | r620_5==2

*5.4 Riks 
gen riesgos=0 if r324!=. & r326!=. & r327!=.
replace riesgos=1 if r324==1 | r326==1 | r327==1


egen num_priv=rowtotal (inasistencia_hog rezago_hog asiste_eduinicial_hog baja_edu_hog roof wall_floor hacinado tenencia subempleo_hog desempleo_hog seguridad_social_hog trab_inf_hog salud_hog inseguridad_alim aguapot sani esparcimiento crimen inseguridad riesgos)

*Multidimensional poverty: PMD
gen PMD=1 if num_priv>=7
replace PMD=0 if num_priv<7

/*
tabout PMD [w=pondera] if r103==1 using "$tabs/Table1.xls", replace
tabout PMD [w=pondera] if r103==1 & pobre==1 using "$tabs/Table1.xls", append
tabout PMD [w=pondera] if r103==1 & pobre==0 using "$tabs/Table1.xls", append
tabout PMD pobre [w=pondera] if r103==1 & urbano==0 using "$tabs/Table1.xls", append
tabout PMD pobre [w=pondera] if r103==1 & urbano==1 using "$tabs/Table1.xls", append
*/

 foreach var in inasistencia_hog rezago_hog asiste_eduinicial_hog baja_edu_hog roof wall_floor hacinado tenencia subempleo_hog desempleo_hog seguridad_social_hog trab_inf_hog ///
 salud_hog inseguridad_alim aguapot sani esparcimiento crimen inseguridad riesgos {
  tabout `var' [w=pondera] if r103==1 & pobre==0 using "$tabs/Table1_Nonpoor.xls",c(col) append
   }
 foreach var in inasistencia_hog rezago_hog asiste_eduinicial_hog baja_edu_hog roof wall_floor hacinado tenencia subempleo_hog desempleo_hog seguridad_social_hog trab_inf_hog ///
 salud_hog inseguridad_alim aguapot sani esparcimiento crimen inseguridad riesgos {
  tabout `var' [w=pondera] if r103==1 & pobre==1 using "$tabs/Table1_Poor.xls",c(col) append
   }


   
   









