**********************************************************************
*El Salvador Poverty and Equity Assessment 2024
**********************************************************************
*Do file: Chapter 2
*Last update: 26/11/2024
**********************************************************************

*Data: 2023

u  "$data/SLV/SLV_2023", replace

*Using right incomes (not adjusted by rurality)
replace ila=ila*p_reg
replace ictap=ictap*p_reg
replace itranp=itranp*p_reg
replace itrane=itrane*p_reg
replace itranext_m=itranext_m*p_reg
replace itranint_m=itranint_m*p_reg
replace icap=icap*p_reg
replace ijubi=ijubi*p_reg
replace ijubi_ncon=ijubi_ncon*p_reg
replace ijubi_con=ijubi_con*p_reg
replace inla_otro=inla_otro*p_reg
replace inla=inla*p_reg

*Generating variable for dependent income
recode ila ictap (.=0)
gen labasal=ila-ictap

*Creating income variables at household level
egen labdf=sum(labasal), by(idboleta)
egen labif=sum(ictap), by(idboleta)
egen retirementcon=sum(ijubi_con), by(idboleta)
egen retirementnocon=sum(ijubi_ncon), by(idboleta)
egen retirement=sum(ijubi), by(idboleta)
egen pubtf=sum(itrane), by(idboleta)
egen pritf=sum(itranp), by(idboleta)
egen pridomf=sum(itranint_m), by(idboleta)
egen priextf=sum(itranext_m), by(idboleta)
egen capitalf=sum(icap), by(idboleta)
egen otrosf=sum(inla_otro), by(idboleta)

egen ingresof=rsum(labdf labif pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1
egen ingnlg=rsum(pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1
tabstat ingnlg if r103==1 & area==1 [w=pondera], stats(mean) by(pobreza)
tabstat ingnlg if r103==1 & area==0 [w=pondera], stats(mean) by(pobreza)



////////////////////////////////////////////////////
//////////////////FIGURES//////////////////////////


***2.1 The importance and precariousness of labor

*****************************
*	Figure 11. Sources of monthly household income, by area of residence and poverty status, 2023 *
*****************************

tabstat labdf labif pubtf pridomf priextf capitalf retirement otrosf if r103==1 & area==1 [w=pondera], stats(mean) by(pobreza)
tabstat labdf labif pubtf pridomf priextf capitalf retirement otrosf if r103==1 & area==0 [w=pondera], stats(mean) by(pobreza)


local row=2
foreach x of numlist 1 2 0 {
preserve

keep if urban==1 & r103==1
	putexcel set "$tabs/Figure11.xls", modify	
	putexcel A1=("Urban") B1=("Salaried labor") C1=("Self-employed labor") D1=("Retirement pensions") E1=("Public transfer") F1=("Private transfers") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ labdf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ labif [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ retirement [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ pritf [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))


	local ++row
restore
}

local row=6
foreach x of numlist 1 2 0 {
preserve

keep if urban==0 & r103==1
	putexcel set "$tabs/Figure11.xls", modify	
	putexcel A1=("Urban") B1=("Salaried labor") C1=("Self-employed labor") D1=("Retirement pensions") E1=("Public transfer") F1=("Private transfers") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ labdf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ labif [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ retirement [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ pritf [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))

	local ++row
restore
}

/*************************** reemplazar todo por esto********************
tabout pobreza using "$tabs/tabla_promedios.xls"    if r103==1 & area==0 [w=pondera], replace sum ///
    c(mean labdf mean labif mean pubtf mean pridomf mean priextf ///
       mean capitalf mean retirement mean otrosf) ///
    f(2) style(xlsx) clab("LabDF" "LabIF" "PubTF" "PriDomF" "PriExtF" "CapitalF" "Retirement" "OtrosF") ///
************************************************************************/
 

*****************************
*	Figure 12. Characterization of the working-age population (thousands), 2023 *
*****************************


gen wap=1 if edad>=16

gen sitlab=1 if wap==1 & actpr2012==10
replace sitlab=2 if wap==1 & actpr2012==20
replace sitlab=3 if wap==1 & actpr2012==30

*Working age
tabout hombre if wap==1 [w=pondera] using "$tabs/Figure12.xls", replace

*EAP/EAP unemployed /EAP inactive
tabout sitlab hombre [w=pondera] if wap==1 using "$tabs/Figure12.xls", append

*Calculating EAP status
replace relab=20 if relab==2 & (r420==1 | r420==3)
replace relab=30 if relab==2 & r420==2
replace relab=20 if relab==2 & r420==.
recode relab (5=.)
tab relab [w=pondera] if wap==1

*Defining formality status
replace tipo_seguro=. if sitlab==2 | sitlab==3 | sitlab==.
gen formal=1 if tipo_seguro<=1 & sitlab==1
replace formal=0 if tipo_seguro==. & sitlab==1

*Calculating formality by type of occupation
tab relab formal if wap==1 [w=pondera]
tab relab formal [w=pondera], row nofreq

*Public employees
tabout hombre if relab==30 & wap==1 [w=pondera] using "$tabs/Figure12.xls", append
*Private employees
tabout hombre if relab==20 & wap==1 [w=pondera] using "$tabs/Figure12.xls", append
*Employers
tabout hombre if relab==1 & wap==1 [w=pondera] using "$tabs/Figure12.xls", append
*Self-employed
tabout hombre if relab==3 & wap==1 [w=pondera] using "$tabs/Figure12.xls", append
*Not salaried
tabout hombre if relab==4 & wap==1 [w=pondera] using "$tabs/Figure12.xls", append


*****************************
*	Figure 13. Labor stability, adequacy, and security along the income distribution, 2023 *
*****************************
xtile deciles [w=pondera]=ingpe, nq(10)

gen ingresofpc=ingresof/miemh_exdomestico
xtile qipc2=ingresofpc [w=pondera], n(10)
* 1. Full time worker =underemployment
gen under=1 if actse==2 | actse==3
replace under=0 if actse==1

gen nounder=0 if under==1
replace nounder=1 if under==0

* 2. Permanent employment
gen permanente=1 if r418==6
replace permanente=0 if r418<=5 | r418>=7

* 3. Informality status
gen informal=1 if formal==0
replace informal=0 if formal==1


tabstat informal if (relab==20 | relab==30) [w=pondera], stats(mean) by(deciles)
tabstat permanente if (relab==20 | relab==30) [w=pondera], stats(mean) by(qipc2)
tabstat under if (relab==20 | relab==30) [w=pondera], stats(mean) by(qipc2)

local row=2
forvalues y = 1(1)10{
preserve
keep if  (relab==20 | relab==30) 

	putexcel set "$tabs/Figure13.xls", modify	
	putexcel B1=("Labor security (formality rate)") C1=("Labor stability (permanent employment rate)") D1=("Labor adequacy (full-time employment rate)")
	*putexcel A`row'=("`y'")
	summ formal [w=pondera] if qipc2==`y'
	putexcel B`row'=(r(mean)*100)
	summ permanente [w=pondera] if qipc2==`y'
	putexcel C`row'=(r(mean)*100)
	summ nounder [w=pondera] if qipc2==`y'
	putexcel D`row'=(r(mean)*100)
	
local ++row	
restore
}

*****************************
*	Figure 14. Schooling premium by type of employment, 2009, 2019, and 2023*
*****************************

use "$data/SLV/SLV_2023", clear
append using "$data/SLV/SLV_2019", force
append using "$data/SLV/SLV_2009", force

cap drop d_informal
gen d_informal = .
		
replace d_informal = djubila == 0 if djubila != .
replace d_informal = . if ocupado != 1 | !inrange(relab,1,4)

keep if cohi==1
		
* Defining sample 
********************
cap drop sample
gen sample = edad > 14 & edad < 65 

* Labor income (main occupation)
*******************************************************
cap drop wage_ppp17
merge m:1 pais ano encuesta  using "$data/IPC SEDLAC/ipc_sedlac_wb.dta", keepusing(ipc17_sedlac ipc_sedlac ppp17 conversion)


gen wage_ppp17 = wage * (ipc17_sedlac / ipc_sedlac) / (ppp17 * conversion)

*UsE wage:
cap drop ln_wh
cap drop ln_whk
gen double ln_wh =ln(wage)
gen double ln_whk=ln(wage)

cap drop exp2
cap drop edad2
cap drop antigue2
gen exp2  = exp*exp 	
gen edad2 = edad*edad 
gen antigue2 = antigue*antigue

*dummies for aedu
cap drop ae_*
replace aedu=17 if aedu>=17


foreach num in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 {
    *drop ae_*
	gen ae_`num'=0
	replace ae_`num'=1 if aedu==`num'
	label variable ae_`num' "`num'"
}

gen Haedu=aedu
replace Haedu=16 if aedu>=16

foreach num in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 {
    *drop Hae_*
	gen Hae_`num'=0
	replace Hae_`num'=1 if Haedu==`num'
	label variable Hae_`num' "`num'"
}

* dummies for aedu by groups
cap drop seg_aedu_*

gen seg_aedu_1=0
replace seg_aedu_1=. if aedu==.
replace seg_aedu_1=1 if aedu > 0 & aedu < 9

gen seg_aedu_2=0
replace seg_aedu_2=. if aedu==.
replace seg_aedu_2=1 if aedu > 8 & aedu < 13

gen seg_aedu_3=0
replace seg_aedu_3=. if aedu==.
replace seg_aedu_3=1 if aedu > 12

label variable seg_aedu_1 "Hasta 8"
label variable seg_aedu_2 "9 a 12"
label variable seg_aedu_3 "13 o más"


*dummies for level of education
tab nivel, gen(niv_)

label variable niv_1 "No asis"
label variable niv_2 "Prim inc"
label variable niv_3 "Prim com"
label variable niv_4 "Sec inc"
label variable niv_5 "Sec com"
label variable niv_6 "Sup inc"
label variable niv_7 "Sup com"


tab nivedu, gen(nivedu_)

foreach num in 1 2 3 {
    label variable niv_`num' "`num'"
}

encode pais, generate(pais_i)

egen internet_casa_h=max(internet_casa), by(pais ano id)   

cap drop itrane_ppp17
gen itrane_ppp17 = itrane * (ipc17_sedlac / ipc_sedlac) / (ppp17 * conversion)
egen h_itrane = sum(itrane_ppp17) if jefe != ., by(pais ano id)

global var_reg Hae_1-Hae_16 edad edad2 i.hombre i.pais_i

// Mincer ecuations:
  **********************
  
// Total workers
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2023
estimates store total2023
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2019
estimates store total2019
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2009
estimates store total2009

// Formal salaried 
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2023 & d_informal==0 & relab==2
estimates store formal2023
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2019 & d_informal==0 & relab==2
estimates store formal2019
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2009 & d_informal==0 & relab==2
estimates store formal2009

// Self-employed
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2023 & relab==3
estimates store self2023
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2019 & relab==3
estimates store self2019
reg ln_wh $var_reg [w=pondera] if ocupado==1 & ano ==2009 & relab==3
estimates store self2009

// Figures

	
coefplot (formal2009, label(2009)) (formal2019, label(2019)) (formal2023, label(2023)), ///
	vertical drop(_cons edad edad2 *hombre *pais_i) yline(0) level(95) ci recast(connected) offset(0) msize(1pt)    ///
	graphregion(color(white)) ///
	legend(rows(1)) ///
	yscale(range(-0.5 2)) ///
	subtitle("Formal salaried")  ///
	title("Premium by year of schooling") ///
	b1title("Years of schooling") ///
	l1title("Schooling premium")
	graph export "$tabs/Figure14a.png", replace

coefplot (self2009, label(2009)) (self2019, label(2019)) (self2023, label(2023)), ///
	vertical drop(_cons edad edad2 *hombre *pais_i) yline(0) level(95) ci recast(connected) offset(0) msize(1pt)    ///
	graphregion(color(white)) ///
	legend(rows(1)) ///
	yscale(range(-0.5 2)) ///
	subtitle("Self-employed")  ///
	title("Premium by year of schooling") ///
	b1title("Years of schooling") ///
	l1title("Schooling premium")
	graph export "$tabs/Figure14b.png", replace




