**********************************************************************
*El Salvador Poverty and Equity Assessment 2024
**********************************************************************
*Do file: Chapter 3
*Last update: 26/11/2024
**********************************************************************


use  "$data/SLV/SLV_2023", replace


label variable pobreza "Pobreza Nacional"
label define pobreza 0"No pobre"1 "Pobre extremo" 2 "Pobre relativo"
label values pobreza pobreza


***3.1 The importance of private transfers on households’ budgets

*Using right incomes (not adjusted by rurality)
replace ila=ila*p_reg
replace ictap=ictap*p_reg
replace itranp=itranp*p_reg
replace itrane=itrane*p_reg
replace itranext_m=itranext_m*p_reg
replace itranint_m=itranint_m*p_reg
replace icap=icap*p_reg
replace ijubi=ijubi*p_reg
replace ijubi_ncon=ijubi_ncon*p_reg
replace ijubi_con=ijubi_con*p_reg
replace inla_otro=inla_otro*p_reg
replace inla=inla*p_reg


*Creating income variables at household level
egen ilaf=sum(ila), by(idboleta)
egen retirementcon=sum(ijubi_con), by(idboleta)
egen retirementnocon=sum(ijubi_ncon), by(idboleta)
egen retirement=sum(ijubi), by(idboleta)
egen pubtf=sum(itrane), by(idboleta)
egen pritf=sum(itranp), by(idboleta)
egen pridomf=sum(itranint_m), by(idboleta)
egen priextf=sum(itranext_m), by(idboleta)
egen capitalf=sum(icap), by(idboleta)
egen otrosf=sum(inla_otro), by(idboleta)


*Creating total households income
egen ingresof=rsum(ilaf pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1


*Creating non-labor household incom
egen ingnlg=rsum(pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf) if r103==1


*****************************
*	Figure 15. Sources of non-labor monthly household income by area of residence and poverty status, 2023 *
*****************************

tabstat pubtf pridomf priextf retirementnocon retirementcon capitalf  otrosf if r103==1 & area==1 [w=pondera], stats(mean) by(pobreza)
tabstat pubtf pridomf priextf retirementnocon retirementcon capitalf  otrosf if r103==1 & area==0 [w=pondera], stats(mean) by(pobreza)

local row=2
foreach x of numlist 1 2 0 {
preserve

keep if urban==1 & r103==1
	putexcel set "$tabs/Figure15.xls", modify	
	putexcel A1=("Urban") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Contributive pensions") F1=("Non-contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ pridomf [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ priextf [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retirementnocon [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retirementcon [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))


	local ++row
restore
}

local row=6
foreach x of numlist 1 2 0 {
preserve

keep if urban==0 & r103==1
	putexcel set "$tabs/Figure15.xls", modify	
	putexcel A5=("Rural") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Non-Contributive pensions") F1=("Contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ pridomf [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ priextf [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retirementnocon [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retirementcon [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))

	local ++row
restore
}

*****************************
*	Figure 17. Access to sources of non-labor income, by area of residence and poverty status, 2023 *
*****************************

* Contributory pensions
gen retcon=1 if retirementcon>0 & retirementcon!=. & r103==1
replace retcon=0 if (retirementcon==0 | retirementcon==.) & r103==1
egen retconf=max(retcon), by(idboleta)
tabstat retcon if edad>=60 [w=pondera], by(hombre)
tabstat retcon if edad>=60 & hombre==1 [w=pondera], by(pobreza)
tabstat retcon if edad>=60 & hombre==0 [w=pondera], by(pobreza)

*Non contributory pensions
gen retnocon=1 if retirementnocon>0 & retirementnocon!=. & r103==1
replace retnocon=0 if (retirementnocon==0 | retirementnocon==.) & r103==1
egen retnoconf=max(retnocon), by(idboleta)
tabstat retnocon if edad>=60 [w=pondera], by(pobreza)
tabstat retnocon if edad>=60 & hombre==1 [w=pondera], by(pobreza)
tabstat retnocon if edad>=60 & hombre==0 [w=pondera], by(pobreza)

*Public transfers
gen pub=1 if pubtf>0 & pubtf!=. & r103==1
replace pub=0 if (pubtf==0 | pubtf==.) & r103==1
egen pubf=max(pub), by(idboleta)

*Domestics transfers
gen dpt=1 if pridomf>0 & pridomf!=. 
replace dpt=0 if (pridomf==0 | pridomf==.)

*Remittances
gen ipt=1 if priextf>0 & priextf!=. 
replace ipt=0 if (priextf==0 | priextf==.) 

*Private transfers
gen pt=ipt|dpt

*Capital

gen cap=1 if capitalf>0 & capitalf!=. & r103==1
replace cap=0 if (capitalf==0 | capitalf==.) & r103==1
egen capf=max(cap), by(idboleta)

*otros
gen otro=1 if otrosf>0 & otrosf!=. & r103==1
replace otro=0 if (otrosf==0 | otrosf==.) & r103==1
egen otrof=max(otro), by(idboleta)


tabstat pub dpt ipt retconf retnoconf cap  otro if r103==1 & area==1 [w=pondera], stats(mean) by(pobreza)
tabstat pub dpt ipt retconf retnoconf cap otro if r103==1 & area==0 [w=pondera], stats(mean) by(pobreza)

local row=2
foreach x of numlist 1 2 0 {
preserve

keep if urban==1 & r103==1
	putexcel set "$tabs/Figure17.xls", modify	
	putexcel A1=("Urban") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Non-Contributive pensions") F1=("Contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pub [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ dpt [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ ipt [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retnoconf [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retconf [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ cap [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otro [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))


	local ++row
restore
}

local row=6
foreach x of numlist 1 2 0 {
preserve

keep if urban==0 & r103==1
	putexcel set "$tabs/Figure17.xls", modify	
	putexcel A5=("Rural") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Non-Contributive pensions") F1=("Contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pub [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ dpt [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ ipt [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retnoconf [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retconf [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ cap [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otro [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))

	local ++row
restore
}

***3.2 Remittances and domestic transfers: a relief with a hidden side 
*****************************
*	Figure 18. Sources of non-labor monthly household income in households that receive remittances, by poverty status, 2023 *
*****************************

tabstat pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf if r103==1 & area==1 & (ipt!=0 & ipt!=.) [w=pondera], stats(mean) by(pobreza)
tabstat pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf if r103==1 & area==0 & (ipt!=0 & ipt!=.) [w=pondera], stats(mean) by(pobreza)

local row=2
foreach x of numlist 1 2 0 {
preserve

keep if urban==1 & r103==1 & (ipt!=0 & ipt!=.)
	putexcel set "$tabs/Figure18.xls", modify	
	putexcel A1=("Urban") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Non-Contributive pensions") F1=("Contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ pridomf [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ priextf [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retirementnocon [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retirementcon [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))



	local ++row
restore
}

local row=6
foreach x of numlist 1 2 0 {
preserve

keep if urban==0 & r103==1 & (ipt!=0 & ipt!=.)
	putexcel set "$tabs/Figure18.xls", modify	
	putexcel A5=("Rural") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Non-Contributive pensions") F1=("Contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ pridomf [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ priextf [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retirementnocon [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retirementcon [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))


	local ++row
restore
}

*****************************
*	Figure 19. Demographics and migration in El Salvador: Population pyramid *
*****************************


recode edad (0/4=1) (5/9=2) (10/14=3) (15/19=4) (20/24=5) (25/29=6) (30/34=7) (35/39=8) (40/44=9) (45/49=10) (50/54=11) (55/59=12) (60/64=13) (65/69=14) (70/74=15) (75/79=16) (80/max=17), gen (cat5)

tabout cat5 [w=pondera] if hombre==1 using "$tabs/Figure19-data-males.xls", replace h3("Hombres") 
tabout cat5 [w=pondera] if hombre==0 using "$tabs/Figure19-data-females.xls", replace h3("Mujeres") 


*****************************
*	Figure 20. Sources of non-labor monthly household income in households that receive domestic transfers in El Salvador, by poverty status, 2023 *
*****************************

tabstat pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf if r103==1 & area==1 & (dpt!=0 & dpt!=.) [w=pondera], stats(mean) by(pobreza)
tabstat pubtf pridomf priextf capitalf retirementnocon retirementcon otrosf if r103==1 & area==0 & (dpt!=0 & dpt!=.) [w=pondera], stats(mean) by(pobreza)

local row=2
foreach x of numlist 1 2 0 {
preserve

keep if urban==1 & r103==1 & (dpt!=0 & dpt!=.)
	putexcel set "$tabs/Figure20.xls", modify	
	putexcel A1=("Urban") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Non-Contributive pensions") F1=("Contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ pridomf [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ priextf [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retirementnocon [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retirementcon [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))



	local ++row
restore
}

local row=6
foreach x of numlist 1 2 0 {
preserve

keep if urban==0 & r103==1 & (dpt!=0 & dpt!=.)
	putexcel set "$tabs/Figure20.xls", modify	
	putexcel A5=("Rural") B1=("Public transfers") C1=("Domestic transfers") D1=("Remittances") E1=("Non-Contributive pensions") F1=("Contributive pensions") G1=("Capital") H1=("Others") 
	putexcel A`row'=("`x'")
	summ pubtf [w=pondera] if pobreza==`x' 
	putexcel B`row'=(r(mean))
	summ pridomf [w=pondera] if pobreza==`x' 
	putexcel C`row'=(r(mean))
	summ priextf [w=pondera] if pobreza==`x' 
	putexcel D`row'=(r(mean))
	summ retirementnocon [w=pondera] if pobreza==`x' 
	putexcel E`row'=(r(mean))
	summ retirementcon [w=pondera] if pobreza==`x' 
	putexcel F`row'=(r(mean))
	summ capitalf [w=pondera] if pobreza==`x' 
	putexcel G`row'=(r(mean))
	summ otrosf [w=pondera] if pobreza==`x' 
	putexcel H`row'=(r(mean))


	local ++row
restore
}
*****************************
*	Figure 21. Extreme poverty in counterfactual scenarios with and without private transfers, 2023 *
*****************************

*Income - remittances - domestic transfers

*SR- without remittances
*SDR - without domestic transfers
*STP - without private transfers (remittances + domestic transfers)

*Figure 21 includes only SR & STP


gen ingfa_sr=ingfa-priext
gen ingfa_sdr=ingfa-pridomf
gen ingfa_stp=ingfa-(priext+pridomf)


gen ingfa_srpc=round(ingfa_sr/miemh_exdomestico, 0.01)
gen ingfa_sdrpc=round(ingfa_sdr/miemh_exdomestico, 0.01)
gen ingfa_stppc=round(ingfa_stp/miemh_exdomestico, 0.01)

cap gen pobreza_sr=0
replace pobreza_sr=1 if ingfa_srpc<lp_extrema
replace pobreza_sr=2 if ingfa_srpc>lp_extrema & ingfa_srpc<lp_moderada

cap gen pobreza_sdr=0
replace pobreza_sdr=1 if ingfa_sdrpc<lp_extrema
replace pobreza_sdr=2 if ingfa_sdrpc>lp_extrema & ingfa_sdrpc<lp_moderada

cap gen pobreza_stp=0
replace pobreza_stp=1 if ingfa_stppc<lp_extrema
replace pobreza_stp=2 if ingfa_stppc>lp_extrema & ingfa_stppc<lp_moderada

*Figure 6 & 9
recode edad (0/14=1) (15/24=2) (25/59=3) (60/max=4), gen(gedad)

forvalues area= 0(1)1 {
preserve

keep if urbano==`area'
foreach y in sr stp {
gen pobrerel=0
replace pobrerel=1 if pobreza_`y'==2

gen pobrex=0
replace pobrex=1 if pobreza_`y'==1

gen nopob=0
replace nopob=1 if pobreza_`y'==0
local row=2
foreach x in pobrex pobrerel nopob pobreext pobremod nopobre {

	putexcel set "$tabs/Figure21-data-`y'-`area'.xls", modify	
	putexcel A1=("Area") B1=("`area'") C1=("Female") D1=("Male") E1=("Age 0-14") F1=("Age 15-24") G1=("Age 25-59") H1=("Age 60+")
	putexcel A`row'=("`x'")
	summ `x' [w=pondera] 
	putexcel B`row'=(r(mean))
	summ `x' [w=pondera] if hombre==0
	putexcel C`row'=(r(mean))
	summ `x' [w=pondera] if hombre==1
	putexcel D`row'=(r(mean))
	summ `x' [w=pondera] if gedad==1
	putexcel E`row'=(r(mean))
	summ `x' [w=pondera] if gedad==2
	putexcel F`row'=(r(mean))
	summ `x' [w=pondera] if gedad==3
	putexcel G`row'=(r(mean))
	summ `x' [w=pondera] if gedad==4
	putexcel H`row'=(r(mean))
	local ++row
}
drop pobrerel pobrex nopob
}
restore
}




