**********************************************************************
*El Salvador Poverty and Equity Assessment 2024
**********************************************************************
*Do file: Chapter 3
*Last update: 26/11/2024
**********************************************************************

use  "$data/SLV/SLV_2023", replace

*****************************
*	Figure 24. Extreme poverty in counterfactual scenarios with and without private transfers, 2023 *
*****************************
recode edad (0/14=1) (15/24=2) (25/59=3) (60/max=4), gen(gedad)

local row=2
foreach x in pobreext {
preserve
keep if urban==1
	putexcel set "$tabs/Figure24.xls", modify	
	putexcel A1=("Area") B1=("Total") C1=("Male") D1=("Female") E1=("Age 0-14") F1=("Age 15-24") G1=("Age 25-59") H1=("Age 60+")
	putexcel A`row'=("`x' urban")
	summ `x' [w=pondera] 
	putexcel B`row'=(r(mean))
	summ `x' [w=pondera] if hombre==1
	putexcel C`row'=(r(mean))
	summ `x' [w=pondera] if hombre==0
	putexcel D`row'=(r(mean))
	summ `x' [w=pondera] if gedad==1
	putexcel E`row'=(r(mean))
	summ `x' [w=pondera] if gedad==2
	putexcel F`row'=(r(mean))
	summ `x' [w=pondera] if gedad==3
	putexcel G`row'=(r(mean))
	summ `x' [w=pondera] if gedad==4
	putexcel H`row'=(r(mean))
	local ++row
restore
}

local row=3
foreach x in pobreext {
preserve
keep if urban==0
	putexcel set "$tabs/Figure24.xls", modify	
	putexcel A1=("Area") B1=("Total") C1=("Female") D1=("Male") E1=("Age 0-14") F1=("Age 15-24") G1=("Age 25-59") H1=("Age 60+")
	putexcel A`row'=("`x' rural ")
	summ `x' [w=pondera] 
	putexcel B`row'=(r(mean))
	summ `x' [w=pondera] if hombre==1
	putexcel C`row'=(r(mean))
	summ `x' [w=pondera] if hombre==0
	putexcel D`row'=(r(mean))
	summ `x' [w=pondera] if gedad==1
	putexcel E`row'=(r(mean))
	summ `x' [w=pondera] if gedad==2
	putexcel F`row'=(r(mean))
	summ `x' [w=pondera] if gedad==3
	putexcel G`row'=(r(mean))
	summ `x' [w=pondera] if gedad==4
	putexcel H`row'=(r(mean))
	local ++row
restore
}



*****************************
*	Figure 25. . Percentage of food insecurity by region, 2023 *
*****************************


* Inseguridad alimentaria: 

* Recode variables r601 to r615 into x601 to x615
foreach var of numlist 601(1)615 {
     recode r`var' (1=1) (2=0), gen(x`var')
}

* Compute variable menor
gen menor = 0
replace menor = 1 if r106 < 18

* Sort cases by idboleta
sort id

* Aggregate to calculate menor_h
egen menor_h = max(menor), by(id)

* Compute variable privali
gen privali = 0

* Calcular privali dependiendo del valor de menor_h
egen privali_temp = rowtotal(x601 x602 x603 x604 x605 x606 x607 x608 x609 x610 x611 x612 x613 x614 x615) if menor_h==1

 egen privali_temp2 = rowtotal(x601 x602 x603 x604 x605 x606 x607 x608) if menor_h==0
 
* Compute variable privali

replace privali=privali_temp if menor_h==1
replace privali=privali_temp2 if menor_h==0

* Recode elcsa based on privali and menor_h
gen elcsa = .
replace elcsa = 1 if privali == 0
replace elcsa = 2 if privali >= 1 & privali <= 3 & menor_h == 0
replace elcsa = 3 if privali >= 4 & privali <= 6 & menor_h == 0
replace elcsa = 4 if privali >= 7 & privali <= 8 & menor_h == 0
replace elcsa = 2 if privali >= 1 & privali <= 5 & menor_h == 1
replace elcsa = 3 if privali >= 6 & privali <= 10 & menor_h == 1
replace elcsa = 4 if privali >= 11 & privali <= 15 & menor_h == 1

label def elcsa 1 "Security" 2 "Mild Insecurity" 3 "Moderate Insecurity" 4 "Severe Insecurity"
label val elcsa elcsa
label var elcsa "Food insecurity index"

* Compute 
gen inseguridad_alim= 0
replace inseguridad_alim = 1 if elcsa >= 3
replace inseguridad_alim = . if r039 > 1 

tabstat inseguridad_alim [w=pondera], stats (mean) by (region_est2)
tabstat inseguridad_alim [w=pondera] if urbano==0, stats (mean) by (region_est2)
tabstat inseguridad_alim [w=pondera] if urbano==1, stats (mean) by (region_est2)

encode region_est2, gen(region)

local row=2 

forvalues x=1/14 {
putexcel set "$tabs/Figure25.xls", modify	
	putexcel A1=("región") B1=("`rate'") C1=("urban") D1=("rural")
	putexcel A`row'=(region_est2)
	summ inseguridad_alim [w=pondera] if (region==`x')
	putexcel B`row'=(r(mean))
	
local ++row
}


