**********************************************************************
*El Salvador Poverty and Equity Assessment 2024
**********************************************************************
*Do file: Table 2
*Last update: 26/11/2024
**********************************************************************

use  "$data/Latinobarometro/Latinobarometro_2023_Esp_Stata_v1_0.dta", replace 

keep if idenpa==222

gen ingresos=1 if S5==1
replace ingresos=2 if S5==4

*1. Acción política

*Respuesta: Nucan en las cuatro: P44ST_A,B,C,D
gen acc_politica=0 
replace acc_politica=1 if P44ST_A==4 & P44ST_B==4  & P44ST_C==4 & P44ST_D==4


tabout acc_politica ingresos using "$tabs/Table2_latinobarometro.xls", replace

*2. Confianza interpersonal

//Pregunta: P9STGBS. Hablando en general, ¿Diría Ud. que se puede confiar en la mayoría de las personas o que uno nunca es lo suficientemente cuidadoso en el trato con los demás? ///
//Respuesta: Respuesta para la falta de confianza: Uno nunca es lo suficientemente cuidadoso en el trato con los demás 

gen conf_inter=0
replace conf_inter=1 if P9STGBS==2

tabout conf_inter ingresos using "$tabs/Table2_latinobarometro.xls", append

*3. Confianza en las instituciones politicas

/*
 Presenta un valor de "3, Poca" o "4, Ninguna" en todas las categorías

P13STGBS.A Confianza en las Fuerzas Armadas (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P13STGBS.B Confianza en la Policía (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P13ST.D Confianza en el Congreso (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P13ST.E Confianza en el Gobierno (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P13ST.F Confianza en el Poder Judicial (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P13ST.H Confianza en la institución electoral del país (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P13ST.I Confianza en el Presidente (perdido, 0; 1-2 = 0; 3 y 4 = 1)
*/

gen conf_institu_polit=0 
replace conf_institu_polit=1 if inlist(P13STGBS_A,3,4) & inlist(P13STGBS_B,3,4) ///
 & inlist(P13ST_D,3,4) & inlist(P13ST_E,3,4) & inlist(P13ST_F,3,4) & inlist(P13ST_H,3,4) & inlist(P13ST_I,3,4) 

tabout conf_institu_polit ingresos using "$tabs/Table2_latinobarometro.xls", append

*4 Cofianza en las instituciones sociales

/*
Presenta un valor de "3, Poca" o "4, Ninguna" en todas las categorías
P13ST.G Confianza en los Partidos Políticos (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P13ST.C Confianza en la Iglesia (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.A Confianza en Bomberos (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.B Confianza en Compañías nacionales (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.E Confianza en Compañías internacionales (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.F Confianza en Bancos (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.C Confianza en Sindicatos (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.D Confianza en Televisión (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.G Confianza en Radio (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14ST.H Confianza en Prensa escrita (perdido, 0; 1-2 = 0; 3 y 4 = 1)
P14N.I Confianza en Redes sociales (perdido, 0; 1-2 = 0; 3 y 4 = 1)
*/

gen conf_institu_soc=0 
replace conf_institu_soc=1 if inlist(P13ST_G,3,4) & inlist(P13ST_C,3,4) ///
 & inlist(P14ST_A,3,4) & inlist(P14ST_B,3,4) & inlist(P14ST_C,3,4) & inlist(P14ST_D,3,4) & inlist(P14ST_E,3,4) ///
  & inlist(P14ST_F,3,4) & inlist(P14ST_G,3,4) & inlist(P14ST_H,3,4) & inlist(P14N_I,3,4) 

tabout conf_institu_soc ingresos using "$tabs/Table2_latinobarometro.xls", append


*5. Satisfacción con la vida

gen satis_vida=0 if P1ST!=-5
replace satis_vida=1 if P1ST==3 | P1ST==4

tabout satis_vida ingresos using "$tabs/Table2_latinobarometro.xls", append


*6.Justicia en la distribución de ingresos

gen just_ing=0 if P17ST>0
replace just_ing=1 if P17ST==3 | P17ST==4

tabout just_ing ingresos using "$tabs/Table2_latinobarometro.xls", append

*7. Tolerancia de la desigualdad 

gen desig=0  if P61ST>0
replace desig=1 if P61ST>=1 & P61ST<=5

tabout desig ingresos using "$tabs/Table2_latinobarometro.xls", append


*8. Garantías sociales

gen garantias_soc=0 
replace garantias_soc=1 if inlist(P41ST_E,3,4) & inlist(P41ST_G,3,4) & inlist(P41ST_L,3,4) ///

tabout garantias_soc ingresos using "$tabs/Table2_latinobarometro.xls", append



*LAPOP

use  "$data/LAPOP/SLV_2023_LAPOP_AmericasBarometer_v1.0_w (1).dta", replace


gen ingresos=1 if q10d==1
replace ingresos=2 if q10d==4

*1. Ausensica de participacion en diferentes espacios sociales

gen no_participa=0
replace no_participa=1 if cp13==4 & cp6==4 & cp7==4 & cp8==4

tabout no_participa ingresos using "$tabs/Table2_lapop.xls", replace

*2. Esperanza en el futuro

gen esp_fut=0 if inlist(mesfut1,1,2,3,4) 
replace esp_fut=1 if mesfut1==3 | mesfut1==4

tabout esp_fut ingresos using "$tabs/Table2_lapop.xls", append

*3. Respeto por las instituciones 

gen resp_insti=0  if b2>=1 & b2<=7
replace resp_insti=1 if inlist(b2,1,2,3) 

tabout resp_insti ingresos using "$tabs/Table2_lapop.xls", append


*4. Proteccion de derechos

gen protec_derechos=0  if b3>=1 & b3<=7
replace protec_derechos=1 if inlist(b3,1,2,3) 

tabout protec_derechos ingresos using "$tabs/Table2_lapop.xls", append



